@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, division, absolute_import
@@ -42,7 +42,6 @@ def set_auth(auth="api_key", profile="DEFAULT"):
 
     Parameters
     ----------
-
     auth: {'api_key', 'resource_principal'}, default 'api_key'
          Enable/disable resource principal identity or keypair identity in a notebook session
     profile: str, default 'DEFAULT'
@@ -76,7 +75,6 @@ def set_debug_mode(mode=True):
 
     Parameters
     ----------
-
     mode: bool (default True)
          Enable/disable print stack traces on notebook
 
@@ -97,11 +95,10 @@ def set_documentation_mode(mode=False):
     This method is deprecated and will be removed in future releases.
     Enable/disable printing user tips on notebook.
 
-        Parameters
-    ads//common/utils.py:572:        return TqdmProgressBar(max_progress, description=description, verbose=is_debug_mode())    ----------
-
-        mode: bool (default False)
-             Enable/disable print user tips on notebook
+    Parameters
+    ----------
+    mode: bool (default False)
+        Enable/disable print user tips on notebook
     """
     global documentation_mode
     documentation_mode = mode
@@ -122,12 +119,12 @@ def set_expert_mode():
 #
 def _set_test_mode(mode=False):
     """
-    Enable/disable intercept the automl call and rewrite it to always use the two algorithms (LogisticRegression for classification and LinearRegression for regression).
+    Enable/disable intercept the automl call and rewrite it to always use
+    the two algorithms (LogisticRegression for classification and LinearRegression for regression).
     Enable only during tests to reduce nb convert notebook tests run time.
 
     Parameters
     ----------
-
     mode: bool (default False)
          Enable/disable the ability to intercept automl call
 
@@ -195,5 +192,3 @@ else:
     import matplotlib.pyplot as plt
 
     plt.switch_backend("agg")
-
-
