@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import, division
@@ -53,7 +53,8 @@ def get_ml_task_type(X, y, classes):
 
     Returns
     -------
-    ml_task_type: A particular task type like `REGRESSION`, `MULTI_CLASS_CLASSIFICATION`...
+    ml_task_type:
+        A particular task type like `REGRESSION`, `MULTI_CLASS_CLASSIFICATION`...
     """
     target_type = TypeDiscoveryDriver().discover(y.name, y)
     if isinstance(target_type, DiscreteTypedFeature):
@@ -87,7 +88,7 @@ class AutoML:
         baseline="dummy",
         client=None,
     ):
-        """
+        r"""
         Creates an Automatic machine learning object.
 
         Parameters
@@ -97,22 +98,21 @@ class AutoML:
         provider : None or object of ads.automl.provider.AutoMLProvider
             If None, the default OracleAutoMLProvider will be used to generate the model
         baseline: None, "dummy", or object of ads.common.model.ADSModel (Default is "dummy")
-            If None, than no baseline is created,
-            If "dummy", than the DummyClassifier or DummyRegressor are used
-            If Object, than whatever estimator is provided will be used.
-              This estimator must include a part of its pipeline which does preprocessing
-              to handle categorical data
-        client: Dask Client to use (optional)
 
+            - If None, than no baseline is created,
+            - If "dummy", than the DummyClassifier or DummyRegressor are used
+            - If Object, than whatever estimator is provided will be used.
 
+            This estimator must include a part of its pipeline which does preprocessing
+            to handle categorical data
+        client:
+            Dask Client to use (optional)
 
         Examples
         --------
-        train, test = ds.train_test_split()
-
-        olabs_automl = OracleAutoMLProvider()
-
-        model, baseline = AutoML(train, provider=olabs_automl).train()
+        >>> train, test = ds.train_test_split()
+        >>> olabs_automl = OracleAutoMLProvider()
+        >>> model, baseline = AutoML(train, provider=olabs_automl).train()
         """
         from ads.automl.provider import OracleAutoMLProvider, BaselineAutoMLProvider
 
@@ -231,7 +231,7 @@ class AutoML:
             )
 
     def train(self, **kwargs):
-        """
+        r"""
         Returns a fitted automl model and a fitted baseline model.
 
         Parameters
@@ -247,11 +247,9 @@ class AutoML:
             the baseline model to compare
         Examples
         --------
-        train, test = ds.train_test_split()
-
-        olabs_automl = OracleAutoMLProvider()
-
-        model, baseline = AutoML(train, provider=olabs_automl).train()
+        >>> train, test = ds.train_test_split()
+        >>> olabs_automl = OracleAutoMLProvider()
+        >>> model, baseline = AutoML(train, provider=olabs_automl).train()
         """
 
         time_budgeted = "time_budget" in kwargs
