@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from IPython.core.display import display
@@ -140,21 +140,15 @@ class ProjectCatalog(Mapping):
         if self.compartment_id is None:
             raise ValueError("compartment_id is required")
 
-        self.ds_client_auth = (
-            ds_client_auth or \
-            auth.default_signer(
-                {"service_endpoint": OCI_ODSC_SERVICE_ENDPOINT}
-                if OCI_ODSC_SERVICE_ENDPOINT
-                else None
-            )
+        self.ds_client_auth = ds_client_auth or auth.default_signer(
+            {"service_endpoint": OCI_ODSC_SERVICE_ENDPOINT}
+            if OCI_ODSC_SERVICE_ENDPOINT
+            else None
         )
-        self.identity_client_auth = (
-            identity_client_auth or \
-            auth.default_signer(
-                {"service_endpoint": OCI_IDENTITY_SERVICE_ENDPOINT}
-                if OCI_IDENTITY_SERVICE_ENDPOINT
-                else None
-            )
+        self.identity_client_auth = identity_client_auth or auth.default_signer(
+            {"service_endpoint": OCI_IDENTITY_SERVICE_ENDPOINT}
+            if OCI_IDENTITY_SERVICE_ENDPOINT
+            else None
         )
 
         self.ds_client = oci_client.OCIClientFactory(**self.ds_client_auth).data_science
