@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import
@@ -88,8 +88,8 @@ class SummaryList(list):
         """
         Returns the model catalog summary as a pandas dataframe
 
-        Paramaters
-        ---------
+        Parameters
+        ----------
         datatime_format: date_format
           A datetime format, like utils.date_format. Defaults to none.
 
@@ -110,8 +110,8 @@ class SummaryList(list):
         """
         Displays the model catalog summary in a Jupyter Notebook cell
 
-        Paramaters
-        ---------
+        Parameters
+        ----------
         date_format: like utils.date_format. Defaults to none.
 
         Returns
