@@ -1,19 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
-
 from bokeh.io import output_notebook
-
-from dask.diagnostics import ResourceProfiler
-
 from IPython import get_ipython
+from ads.common.deprecate import deprecated
+
+try:
+    from dask.diagnostics import ResourceProfiler
+except ImportError as e:
+    raise ModuleNotFoundError("Install dask to use the analyzer class.") from e
 
 if get_ipython():
     output_notebook()
 
 
+@deprecated("2.5.2")
 def resource_analyze(dask_fun):
     """
     Profiles Dask operation and renders profiler output as a bokeh graph.
