@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import oci
@@ -30,9 +30,10 @@ def api_keys(
     -------
     dict
         Contains keys - config, signer and client_kwargs.
-         * The config contains the config loaded from the configuration loaded from `oci_config`.
-         * The signer contains the signer object created from the api keys.
-         * client_kwargs contains the `client_kwargs` that was passed in as input parameter.
+
+        - The config contains the config loaded from the configuration loaded from `oci_config`.
+        - The signer contains the signer object created from the api keys.
+        - client_kwargs contains the `client_kwargs` that was passed in as input parameter.
 
     Examples
     --------
@@ -68,9 +69,10 @@ def resource_principal(client_kwargs=None):
     -------
     dict
         Contains keys - config, signer and client_kwargs.
-         * The config contains and empty dictionary.
-         * The signer contains the signer object created from the resource principal.
-         * client_kwargs contains the `client_kwargs` that was passed in as input parameter.
+
+        - The config contains and empty dictionary.
+        - The signer contains the signer object created from the resource principal.
+        - client_kwargs contains the `client_kwargs` that was passed in as input parameter.
 
     Examples
     --------
@@ -100,10 +102,11 @@ def default_signer(client_kwargs=None):
     -------
     dict
         Contains keys - config, signer and client_kwargs.
-         * The config contains the config loaded from the configuration loaded from the default location if the default
-         auth mode is API keys, otherwise it is empty dictionary.
-         * The signer contains the signer object created from default auth mode.
-         * client_kwargs contains the `client_kwargs` that was passed in as input parameter.
+
+        - The config contains the config loaded from the configuration loaded from the default location if the default
+          auth mode is API keys, otherwise it is empty dictionary.
+        - The signer contains the signer object created from default auth mode.
+        - client_kwargs contains the `client_kwargs` that was passed in as input parameter.
 
     Examples
     --------
@@ -117,3 +120,10 @@ def default_signer(client_kwargs=None):
         return resource_principal(client_kwargs)
     else:
         return api_keys(client_kwargs=client_kwargs, profile=utils.oci_key_profile())
+
+
+def get_signer(oci_config=None, oci_profile=None, **client_kwargs):
+    if oci_config and oci_profile:
+        return api_keys(oci_config, oci_profile, client_kwargs)
+    else:
+        return resource_principal(client_kwargs)
