@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import yaml
@@ -119,12 +119,16 @@ def write_score(path, **kwargs):
         kwargs.get("misc_imports", list())
         + get_function_config()["models"][serializer]["misc_imports"]
     )
-    sklearn_model = kwargs.get("underlying_model", "NOTFOUND") in ["sklearn", "xgboost"]
+    underlying_model = kwargs.get("underlying_model", "NOTFOUND")
+    sklearn_model = underlying_model in ["sklearn", "xgboost"]
 
-    jinja_template_filename = kwargs.get(
-        "input_file",
-        get_function_config()["models"][serializer].get("input_file", "score"),
-    )
+    if underlying_model == "automl":
+        jinja_template_filename = "score-pkl-automl"
+    else:
+        jinja_template_filename = kwargs.get(
+            "input_file",
+            get_function_config()["models"][serializer].get("input_file", "score"),
+        )
     scorefn_template = env.get_template(f"{jinja_template_filename}.jinja2")
     with open(os.path.join(path, "score.py"), "w") as sfl:
         sfl.write(
