@@ -1,19 +1,17 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import distutils
 import os
 import shutil
 from collections import Iterable
-from distutils.dir_util import copy_tree
 
 import numpy as np
 import pandas as pd
 from ads.common import logger, utils
-from ads.common.model_artifact import ModelArtifact
 from ads.common.model_export_util import (
     ONNXTransformer,
     Progress_Steps_W_Fn,
@@ -33,7 +31,7 @@ from sklearn.pipeline import Pipeline
 
 
 Unsupported_Model_Types = []
-NoTransformModels = ["torch", "tensorflow", "keras"]
+NoTransformModels = ["torch", "tensorflow", "keras", "automl"]
 
 
 class ADSModel(object):
@@ -384,6 +382,7 @@ class ADSModel(object):
         ignore_deployment_error=False,
         use_case_type=None,
         inference_python_version=None,
+        **kwargs,
     ):
         """
         Prepare model artifact directory to be published to model catalog
@@ -422,6 +421,11 @@ class ADSModel(object):
         inference_python_version: str, default:None.
             If provided will be added to the generated runtime yaml
 
+        **kwargs
+        --------
+        max_col_num: (int, optional). Defaults to utils.DATA_SCHEMA_MAX_COL_NUM.
+            The maximum column size of the data that allows to auto generate schema.
+
         Returns
         -------
         model_artifact: an instance of `ModelArtifact` that can be used to test the generated scoring script
@@ -489,6 +493,7 @@ class ADSModel(object):
                 y=y_trans,
                 model_type=self._underlying_model,
             )
+            max_col_num = kwargs.get("max_col_num", utils.DATA_SCHEMA_MAX_COL_NUM)
 
             if self._underlying_model not in NoTransformModels:
                 try:
@@ -511,7 +516,7 @@ class ADSModel(object):
             model_kwargs["data_science_env"] = data_science_env
             model_kwargs["ignore_deployment_error"] = ignore_deployment_error
             model_kwargs["use_case_type"] = use_case_type
-
+            model_kwargs["max_col_num"] = max_col_num
             model_artifact = prepare_generic_model(
                 target_dir,
                 model=self.est,
@@ -525,7 +530,10 @@ class ADSModel(object):
                 **model_kwargs,
             )
             try:
-                model_artifact.reload(model_file_name="model.onnx")
+                model_file_name = (
+                    "model.pkl" if self._underlying_model == "automl" else "model.onnx"
+                )
+                model_artifact.reload(model_file_name=model_file_name)
             except Exception as e:
                 print(str(e))
                 msg = (
