@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import fnmatch
@@ -49,7 +49,7 @@ from ads.common.model_metadata import (
     MetadataTaxonomyKeys,
     UseCaseType,
 )
-from ads.common.utils import InvalidObjectStoragePath
+from ads.common.utils import InvalidObjectStoragePath, DATA_SCHEMA_MAX_COL_NUM
 from ads.config import (
     NB_SESSION_OCID,
     JOB_RUN_OCID,
@@ -57,7 +57,7 @@ from ads.config import (
     NB_SESSION_COMPARTMENT_OCID,
 )
 import ads.dataset.factory as factory
-from ads.feature_engineering.schema import Schema, SchemaSizeTooLarge
+from ads.feature_engineering.schema import Schema, SchemaSizeTooLarge, DataSizeTooWide
 
 from git import InvalidGitRepositoryError, Repo
 from oci.data_science.models import ModelProvenance
@@ -300,7 +300,7 @@ class ModelArtifact(Introspectable):
                     pack_bucket = user_config["bucket_info"]["name"]
                     pack_namespace = user_config["bucket_info"]["namespace"]
                 else:
-                    logger.warn(
+                    logger.warning(
                         f"Cannot resolve the bucket name and namespace details for the conda environment {conda_prefix}. "
                         f"You can set these values while saving the model or run `odsc init -b *bucket-name* -n *namespace*` from the terminal and then rerun prepare step again."
                     )
@@ -1484,6 +1484,7 @@ class ModelArtifact(Introspectable):
         data_sample: ADSData = None,
         X_sample: Union[list, tuple, pd.DataFrame, pd.Series, np.ndarray] = None,
         y_sample: Union[list, tuple, pd.DataFrame, pd.Series, np.ndarray] = None,
+        max_col_num: int = DATA_SCHEMA_MAX_COL_NUM,
     ):
         """
         Populates input schema and output schema.
@@ -1493,10 +1494,12 @@ class ModelArtifact(Introspectable):
         ----------
         data_sample: ADSData
             A sample of the data that will be used to generate intput_schema and schema_output.
-        X_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame, dask.dataframe.core.Series, dask.dataframe.core.DataFrame]
+        X_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame]
             A sample of input data that will be used to generate input schema.
-        y_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame, dask.dataframe.core.Series, dask.dataframe.core.DataFrame]
+        y_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame]
             A sample of output data that will be used to generate output schema.
+        max_col_num: (int, optional). Defaults to utils.DATA_SCHEMA_MAX_COL_NUM.
+            The maximum column size of the data that allows to auto generate schema.
         """
         if data_sample is not None:
             assert isinstance(
@@ -1508,13 +1511,15 @@ class ModelArtifact(Introspectable):
         self.schema_input = self._populate_schema(
             X_sample,
             schema_file_name=INPUT_SCHEMA_FILE_NAME,
+            max_col_num=max_col_num,
         )
         self.schema_output = self._populate_schema(
             y_sample,
             schema_file_name=OUTPUT_SCHEMA_FILE_NAME,
+            max_col_num=max_col_num,
         )
 
-    def _populate_schema(self, data, schema_file_name):
+    def _populate_schema(self, data, schema_file_name, max_col_num):
         """
         Populate schema and if the schema exceeds the limit of 32kb, save as a json file to the artifact_dir.
 
@@ -1522,18 +1527,30 @@ class ModelArtifact(Introspectable):
         ----------
         data_sample: ADSData
             A sample of the data that will be used to generate intput_schema and schema_output.
-        X_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame, dask.dataframe.core.Series, dask.dataframe.core.DataFrame]
+        X_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame]
             A sample of input data that will be used to generate input schema.
-        y_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame, dask.dataframe.core.Series, dask.dataframe.core.DataFrame]
+        y_sample: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame]
             A sample of output data that will be used to generate output schema.
+        max_col_num : int
+            The maximum column size of the data that allows to auto generate schema.
         """
-        if data is not None:
-            data = utils.to_dataframe(data)
-            schema = data.ads.model_schema()
-            schema.to_json_file(os.path.join(self.artifact_dir, schema_file_name))
-            if self._validate_schema_size(schema, schema_file_name):
-                return schema
-        return Schema()
+        result = None
+
+        try:
+            if data is not None:
+                data = utils.to_dataframe(data)
+                schema = data.ads.model_schema(max_col_num=max_col_num)
+                schema.to_json_file(os.path.join(self.artifact_dir, schema_file_name))
+                if self._validate_schema_size(schema, schema_file_name):
+                    result = schema
+        except DataSizeTooWide:
+            logger.warning(
+                f"The data has too many columns and "
+                f"the maximum allowable number of columns is `{max_col_num}`. "
+                "The schema was not auto generated. increase allowable number of columns."
+            )
+
+        return result or Schema()
 
     def _validate_schema_size(self, schema, schema_file_name):
         result = False
