@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import json
@@ -11,12 +11,10 @@ import onnx
 import onnxmltools
 import os
 import pandas as pd
-import shutil
 import sys
-import dask
 from typing import Union
 
-from jinja2 import Environment, PackageLoader
+import cloudpickle
 from ads.common import logger, utils
 from ads.common.function.fn_util import (
     get_function_config,
@@ -26,6 +24,7 @@ from ads.common.function.fn_util import (
 from ads.common.data import ADSData
 from ads.common.model_artifact import ModelArtifact
 from ads.common.model_metadata import UseCaseType
+from ads.feature_engineering.schema import DataSizeTooWide
 from pkg_resources import get_distribution
 from skl2onnx.common.data_types import (
     FloatTensorType,
@@ -56,7 +55,7 @@ OnnxConvertibleModels = [
     "mxnet",
 ]
 NoVerifyModels = ["automl", "torch", "mxnet", "lightgbm", "xgboost", "torch"]
-AlreadyWrittenModels = ["torch", "mxnet"]
+AlreadyWrittenModels = ["torch", "mxnet", "automl"]
 TransformableData = ["automl"]
 Progress_Steps_W_Fn = 6
 Progress_Steps_Wo_Fn = 4
@@ -76,8 +75,6 @@ def prepare_generic_model(
         pd.Series,
         np.ndarray,
         pd.DataFrame,
-        dask.dataframe.core.Series,
-        dask.dataframe.core.DataFrame,
     ] = None,
     y_sample: Union[
         list,
@@ -85,8 +82,6 @@ def prepare_generic_model(
         pd.Series,
         np.ndarray,
         pd.DataFrame,
-        dask.dataframe.core.Series,
-        dask.dataframe.core.DataFrame,
     ] = None,
     **kwargs,
 ) -> ModelArtifact:
@@ -98,52 +93,6 @@ def prepare_generic_model(
     * requirements.txt
     * score.py
 
-    Usage:
-    -----
-    >>> import cloudpickle
-    >>> import os
-    >>> from sklearn.linear_model import LogisticRegression
-    >>> from sklearn.datasets import make_classification
-    >>> import ads
-    >>> from ads.common.model_export_util import prepare_generic_model
-    >>> import yaml
-    >>>
-    >>> ads.set_auth('api_key', profile='DEFAULT')
-    >>> model_artifact_location = os.path.expanduser('~/myusecase/model/')
-    >>> inference_conda_env="oci://my-bucket@namespace/conda_environments/cpu/Data Exploration and Manipulation for CPU Python 3.7/2.0/dataexpl_p37_cpu_v2"
-    >>> inference_python_version = "3.7"
-    >>> if not os.path.exists(model_artifact_location):
-    ...     os.makedirs(model_artifact_location)
-    >>> X, y = make_classification(n_samples=100, n_features=20, n_classes=2)
-    >>> lrmodel = LogisticRegression().fit(X, y)
-    >>> with open(os.path.join(model_artifact_location, 'model.pkl'), "wb") as mfile:
-    ...     cloudpickle.dump(lrmodel, mfile)
-    >>> modelartifact = prepare_generic_model(
-    ...     model_artifact_location,
-    ...     model = 'model.pkl',
-    ...     force_overwrite=True,
-    ...     inference_conda_env=inference_conda_env,
-    ...     ignore_deployment_error=True,
-    ...     inference_python_version=inference_python_version
-    ... )
-    >>> modelartifact.reload() # Call reload to update the ModelArtifact object with the generated score.py
-    >>> assert len(modelartifact.predict(X[:5])['prediction']) == 5 #Test the generated score.py works. This may require customization.
-    >>> with open(os.path.join(model_artifact_location, "runtime.yaml")) as rf:
-    ...     content = yaml.load(rf, Loader=yaml.FullLoader)
-    ...     assert content['MODEL_DEPLOYMENT']['INFERENCE_CONDA_ENV']['INFERENCE_ENV_PATH'] == inference_conda_env
-    ...     assert content['MODEL_DEPLOYMENT']['INFERENCE_CONDA_ENV']['INFERENCE_PYTHON_VERSION'] == inference_python_version
-    >>> # Save Model to model artifact
-    >>> ocimodel = modelartifact.save(
-    ...     project_id="oci1......", # OCID of the project to which the model to be associated
-    ...     compartment_id="oci1......", # OCID of the compartment where the model will reside
-    ...     display_name="LRModel_01",
-    ...     description="My Logistic Regression Model",
-    ...     ignore_pending_changes=True,
-    ...     timeout=100,
-    ...     ignore_introspection=True,
-    ... )
-    >>> print(f"The OCID of the model is: {ocimodel.id}")
-
     Parameters
     ----------
     model_path : str
@@ -187,6 +136,54 @@ def prepare_generic_model(
         max number of progress.
     inference_python_version: str, default:None.
         If provided will be added to the generated runtime yaml
+    max_col_num: (int, optional). Defaults to utils.DATA_SCHEMA_MAX_COL_NUM.
+        The maximum column size of the data that allows to auto generate schema.
+
+    Examples
+    --------
+    >>> import cloudpickle
+    >>> import os
+    >>> from sklearn.linear_model import LogisticRegression
+    >>> from sklearn.datasets import make_classification
+    >>> import ads
+    >>> from ads.common.model_export_util import prepare_generic_model
+    >>> import yaml
+    >>>
+    >>> ads.set_auth('api_key', profile='DEFAULT')
+    >>> model_artifact_location = os.path.expanduser('~/myusecase/model/')
+    >>> inference_conda_env="oci://my-bucket@namespace/conda_environments/cpu/Data Exploration and Manipulation for CPU Python 3.7/2.0/dataexpl_p37_cpu_v2"
+    >>> inference_python_version = "3.7"
+    >>> if not os.path.exists(model_artifact_location):
+    ...     os.makedirs(model_artifact_location)
+    >>> X, y = make_classification(n_samples=100, n_features=20, n_classes=2)
+    >>> lrmodel = LogisticRegression().fit(X, y)
+    >>> with open(os.path.join(model_artifact_location, 'model.pkl'), "wb") as mfile:
+    ...     cloudpickle.dump(lrmodel, mfile)
+    >>> modelartifact = prepare_generic_model(
+    ...     model_artifact_location,
+    ...     model = 'model.pkl',
+    ...     force_overwrite=True,
+    ...     inference_conda_env=inference_conda_env,
+    ...     ignore_deployment_error=True,
+    ...     inference_python_version=inference_python_version
+    ... )
+    >>> modelartifact.reload() # Call reload to update the ModelArtifact object with the generated score.py
+    >>> assert len(modelartifact.predict(X[:5])['prediction']) == 5 #Test the generated score.py works. This may require customization.
+    >>> with open(os.path.join(model_artifact_location, "runtime.yaml")) as rf:
+    ...     content = yaml.load(rf, Loader=yaml.FullLoader)
+    ...     assert content['MODEL_DEPLOYMENT']['INFERENCE_CONDA_ENV']['INFERENCE_ENV_PATH'] == inference_conda_env
+    ...     assert content['MODEL_DEPLOYMENT']['INFERENCE_CONDA_ENV']['INFERENCE_PYTHON_VERSION'] == inference_python_version
+    >>> # Save Model to model artifact
+    >>> ocimodel = modelartifact.save(
+    ...     project_id="oci1......", # OCID of the project to which the model to be associated
+    ...     compartment_id="oci1......", # OCID of the compartment where the model will reside
+    ...     display_name="LRModel_01",
+    ...     description="My Logistic Regression Model",
+    ...     ignore_pending_changes=True,
+    ...     timeout=100,
+    ...     ignore_introspection=True,
+    ... )
+    >>> print(f"The OCID of the model is: {ocimodel.id}")
 
     Returns
     -------
@@ -216,19 +213,18 @@ def prepare_generic_model(
         "model_libs", {}
     )  # utils.extract_lib_dependencies_from_model(self.est)
     progress = kwargs.get("progress", None)
+    max_col_num = kwargs.get("max_col_num", utils.DATA_SCHEMA_MAX_COL_NUM)
     artifact_type_generic = progress is not None
 
     from ads.common.model import ADSModel
 
-    if isinstance(model, ADSModel):
+    if isinstance(model, ADSModel) and underlying_model != "automl":
         raise ValueError(
             "Only generic model can be used to generate generic model artifact."
         )
 
     if use_case_type and use_case_type not in UseCaseType:
-        raise ValueError(
-            f"Invalid usecase type. Please choose from {UseCaseType.values()}"
-        )
+        raise ValueError(f"Invalid usecase type. Choose from {UseCaseType.values()}")
 
     with progress if artifact_type_generic else utils.get_progress_bar(
         Progress_Steps_W_Fn if fn_artifact_files_included else Progress_Steps_Wo_Fn
@@ -315,9 +311,14 @@ def prepare_generic_model(
                 data_sample,
                 X_sample,
                 y_sample,
+                max_col_num,
+            )
+        except DataSizeTooWide:
+            logger.warning(
+                f"The data has too many columns and "
+                f"the maximum allowable number of columns is `{max_col_num}`. "
+                "The schema was not auto generated. increase allowable number of columns."
             )
-        except:
-            logger.warning("Failed to populate the input and output schema.")
 
         return model_artifact
 
@@ -356,7 +357,7 @@ def serialize_model(
         if model_type == "sklearn":
             onx = _sklearn_to_onnx(model=model)
         elif model_type == "automl":
-            onx = _automl_to_onnx(model=model, X=X, y=y)
+            _automl_to_pkl(model=model, target_dir=target_dir)
         elif model_type == "lightgbm":
             onx = _lightgbm_to_onnx(model=model, X=X, y=y)
         elif model_type == "torch":
@@ -380,8 +381,12 @@ def serialize_model(
                 f.write(onx.SerializeToString())
 
         # Lastly, set the necessary env variables for the remaining workflow
-        model_kwargs["model_name"] = "model.onnx"
-        model_kwargs["serializer"] = "onnx"
+        if model_type == "automl":
+            model_kwargs["model_name"] = "model.pkl"
+            model_kwargs["serializer"] = "pkl"
+        else:
+            model_kwargs["model_name"] = "model.onnx"
+            model_kwargs["serializer"] = "onnx"
     except Exception as e:
         logger.error(
             f"Failed to serialize the model as ONNX returned the error message::{e}."
@@ -404,19 +409,10 @@ def _sklearn_to_onnx(model=None, target_dir=None, X=None, y=None, **kwargs):
     )
 
 
-def _automl_to_onnx(model=None, target_dir=None, X=None, y=None, **kwargs):
-    if not hasattr(model, "to_onnx"):
-        logger.error(
-            "This version of AutoML does not support ONNX serialization. "
-            "Upgrade to version >= 0.5.0.",
-        )
-        raise Exception("Serialization not supported, please upgrade automl>=0.5.0")
-    if X is None:
-        raise Exception(
-            "To serialize an Oracle Labs automl model, please pass in an example of the dataset."
-        )
-    onx = model.to_onnx(X, y)
-    return onx
+def _automl_to_pkl(model=None, target_dir=None, **kwargs):
+
+    with open(os.path.join(target_dir, "model.pkl"), "wb") as outfile:
+        cloudpickle.dump(model, outfile)
 
 
 def _lightgbm_to_onnx(model=None, target_dir=None, X=None, y=None, **kwargs):
@@ -584,7 +580,7 @@ def _mxnet_to_onnx(model=None, target_dir=None, X=None, y=None, **kwargs):
     sym = kwargs.get("sym", None)
     params = kwargs.get("params", None)
     assert sym is not None and params is not None, (
-        "Please pass `sym` [Path to the json file or Symbol object] and "
+        "Pass `sym` [Path to the json file or Symbol object] and "
         "`params` [Path to the params file or params dictionary. "
         "(Including both arg_params and aux_params)] to kwargs"
     )
@@ -607,23 +603,24 @@ def _log_automatic_serialization_keras(e):
     )
 
 
-# # Note to developers: If you make any changes to this class, please copy and paste those changes over to
+# # Note to developers: If you make any changes to this class, copy and paste those changes over to
 # templates/score.jinja2. We do not yet have an automatic way of doing this.
 class ONNXTransformer(object):
     """
     This is a transformer to convert X [pandas.Dataframe, dask.Dataframe, equivalent] and y [array like] data into Onnx
     readable dtypes and formats. It is Serializable, so it can be reloaded at another time.
 
-    Usage:
-    >>> from ads.common.model_export_util import ONNXTransformer
-    >>> onnx_data_transformer = ONNXTransformer(task="classification")
-    >>> train_transformed = onnx_data_transformer.fit_transform(train.X, train.y)
-    >>> test_transformed = onnx_data_transformer.transform(test.X, test.y)
-
     Parameters
     ----------
     task: str
         Either "classification" or "regression". This determines if y should be label encoded
+
+    Examples
+    --------
+    >>> from ads.common.model_export_util import ONNXTransformer
+    >>> onnx_data_transformer = ONNXTransformer(task="classification")
+    >>> train_transformed = onnx_data_transformer.fit_transform(train.X, train.y)
+    >>> test_transformed = onnx_data_transformer.transform(test.X, test.y)
     """
 
     def __init__(self, task=None):
