@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 """
@@ -114,7 +114,7 @@ class Introspectable(ABC):
 class ModelIntrospect:
     """Class to introspect model artifacts.
 
-    Properties
+    Parameters
     ----------
     status: str
         Returns the current status of model introspection.
