@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 
@@ -598,7 +598,7 @@ class ModelCustomMetadataItem(ModelTaxonomyMetadataItem):
         if category not in MetadataCustomCategory:
             raise ValueError(
                 f"Invalid category value for the {self.key}. "
-                f"Please choose from {MetadataCustomCategory.values()}."
+                f"Choose from {MetadataCustomCategory.values()}."
             )
 
         self._category = category
@@ -663,7 +663,7 @@ class ModelCustomMetadataItem(ModelTaxonomyMetadataItem):
         if self.category and self.category not in MetadataCustomCategory:
             raise ValueError(
                 f"Invalid category value for the {self.key}. "
-                f"Please choose from {MetadataCustomCategory.values()}."
+                f"Choose from {MetadataCustomCategory.values()}."
             )
 
         if self.value:
@@ -1100,7 +1100,7 @@ class ModelCustomMetadata(ModelMetadata):
         if category not in MetadataCustomCategory:
             raise ValueError(
                 f"Invalid category value. "
-                f"Please choose from {MetadataCustomCategory.values()}."
+                f"Choose from {MetadataCustomCategory.values()}."
             )
 
         if description and not isinstance(description, str):
