@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 import logging
 
@@ -24,8 +24,8 @@ class OCIClientFactory:
     A factory class to create OCI client objects. The constructor takes in config, signer and client_kwargs. `client_kwargs` is passed
     to the client constructor as key word argutments.
 
-    Usage
-    -----
+    Examples
+    --------
     from ads.common import auth as authutil
     from ads.common import oci_client as oc
 
