@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import
@@ -14,17 +14,15 @@ from enum import Enum
 from textwrap import fill
 import re
 import os
-import psutil
-import random, string
+import random
+import string
 from pandas.core.dtypes.common import is_numeric_dtype, is_datetime64_dtype
 
-import dask.dataframe as dd
 import numpy as np
 import pandas as pd
 from IPython import get_ipython
-import dask
 
-from sklearn.model_selection import train_test_split as sklearn_train_test_split
+from sklearn.model_selection import train_test_split
 
 from IPython.core.display import display, HTML
 
@@ -65,22 +63,32 @@ mpl.rcParams["axes.prop_cycle"] = cycler(
 # sqlalchemy engines
 _engines = {}
 
+ORACLE_DEFAULT_PORT = 1521
+MYSQL_DEFAULT_PORT = "3306"
+
+# Maximum number of columns of data to extract model schema.
+DATA_SCHEMA_MAX_COL_NUM = 2000
+
+# declare custom exception class
+class FileOverwriteError(Exception):
+    pass
+
 
 # get number of core count
 def get_cpu_count():
     """
     Returns the number of CPUs available on this machine
     """
-    return psutil.cpu_count()
+    from cpuinfo import get_cpu_info
+
+    return get_cpu_info()["count"]
 
 
+@deprecated(
+    "2.5.2", details="This method is being deprecated in favor of `get_cpu_count`"
+)
 def get_compute_accelerator_ncores():
-    """
-    Returns the number of accelerator cores
-    """
-    from ads.environment import ml_runtime
-
-    return sum(ml_runtime.compute_accelerator().ncores().values())
+    return get_cpu_count()
 
 
 def get_oci_config():
@@ -679,26 +687,19 @@ class JsonConverter(json.JSONEncoder):
 
 def split_data(X, y, random_state=random_state, test_size=test_size):
     """
-    Splits data using either Dask or Sklearn based on the input type of the data.
+    Splits data using Sklearn based on the input type of the data.
 
     Parameters
     ----------
-    X: Either a Pandas or Dask Dataframe
+    X: a Pandas Dataframe
         The data points.
-    y: Either a Pandas or Dask Dataframe
+    y: a Pandas Dataframe
         The labels.
     random_state: int
         A random state for reproducability.
     test_size: int
         The number of elements that should be included in the test dataset.
     """
-    from dask_ml.model_selection import train_test_split as dask_train_test_split
-
-    train_test_split = (
-        dask_train_test_split
-        if isinstance(X, dd.core.DataFrame)
-        else sklearn_train_test_split
-    )
     return train_test_split(
         X, y, train_size=1 - test_size, test_size=test_size, random_state=random_state
     )
@@ -709,7 +710,7 @@ def get_sqlalchemy_engine(connection_url, *args, **kwargs):
     The SqlAlchemny docs say to use a single engine per connection_url, this class will take
     care of that.
 
-    Parameters:
+    Parameters
     ----------
 
     connection_url: string
@@ -892,8 +893,6 @@ def to_dataframe(
         pd.Series,
         np.ndarray,
         pd.DataFrame,
-        dask.dataframe.core.Series,
-        dask.dataframe.core.DataFrame,
     ]
 ):
     """
@@ -901,7 +900,7 @@ def to_dataframe(
 
     Parameters
     ----------
-    data: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame, dask.dataframe.core.Series, dask.dataframe.core.DataFrame]
+    data: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame]
         Convert data to pandas DataFrame.
 
     Returns
@@ -928,7 +927,7 @@ def to_dataframe(
             )
     elif isinstance(data, pd.DataFrame):
         return data
-    elif isinstance(data, dask.dataframe.core.DataFrame):
+    elif _is_dask_dataframe(data):
         return data.compute()
     else:
         raise NotImplementedError(
@@ -942,11 +941,37 @@ class InvalidObjectStoragePath(Exception):
     pass
 
 
+def _is_dask_dataframe(ddf):
+    """
+    Will determine if the given arg is a dask dataframe.
+    Returns False if dask is not installed.
+    """
+    try:
+        import dask.dataframe as dd
+
+        return isinstance(ddf, dd.DataFrame)
+    except:
+        return False
+
+
+def _is_dask_series(ddf):
+    """
+    Will determine if the given arg is a dask dataframe.
+    Returns False if dask is not installed.
+    """
+    try:
+        import dask.dataframe as dd
+
+        return isinstance(ddf, dd.Series)
+    except:
+        return False
+
+
 def _log_missing_module(module, package):
     """
     Log message for missing module
     """
-    logger.info(f"The {module} module was not found. Install {package}.")
+    logger.error(f"The {module} module was not found. Install {package}.")
 
 
 def _log_multivalue_feature_column_error():
@@ -966,3 +991,46 @@ def _snake_to_camel(name, capitalized_first_token=False):
     return (tokens[0].capitalize() if capitalized_first_token else tokens[0]) + "".join(
         x.capitalize() if not x.isupper() else x for x in tokens[1:]
     )
+
+
+def is_data_too_wide(
+    data: Union[
+        list,
+        tuple,
+        pd.Series,
+        np.ndarray,
+        pd.DataFrame,
+    ],
+    max_col_num: int,
+) -> bool:
+    """
+    Returns true if the data has too many columns.
+
+    Parameters
+    ----------
+
+    data: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame]
+        A sample of data that will be used to generate schema.
+    max_col_num : int.
+        The maximum column size of the data that allows to auto generate schema.
+    """
+    assert (
+        max_col_num and isinstance(max_col_num, int) and max_col_num > 0
+    ), "The parameter `max_col_num` must be a positive integer."
+
+    data_type = type(data)
+    if data_type == pd.Series or _is_dask_series(data):
+        return False
+    elif data_type == pd.DataFrame or _is_dask_dataframe(data):
+        col_num = len(data.columns)
+    elif (
+        # check the column size in model_schema() after converting to pd.dataframe
+        isinstance(data, np.ndarray)
+        or isinstance(data, list)
+        or isinstance(data, tuple)
+    ):
+        return False
+    else:
+        raise TypeError(f"The data type `{type(data)}` is not supported.")
+
+    return col_num > max_col_num
