@@ -1,6 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: utf-8; -*-# Copyright (c) 2021 Oracle and/or its affiliates.
+# -*- coding: utf-8; -*-
 
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from typing import Any, Dict
@@ -20,7 +21,6 @@ class MetadataParser(Parser):
         "labelsSet",
         "annotationFormat",
         "datasetSourceDetails",
-        "recordFiles",
         "datasetFormatDetails",
     ]
 
@@ -44,11 +44,15 @@ class MetadataParser(Parser):
             json_data["datasetSourceDetails"]["namespace"],
             json_data["datasetSourceDetails"]["prefix"],
         ).path
-        records_path = ObjectStorageDetails(
-            json_data["recordFiles"][0]["bucket"],
-            json_data["recordFiles"][0]["namespace"],
-            json_data["recordFiles"][0]["path"],
-        ).path
+
+        records_path = ""
+        if "recordFiles" in json_data:
+            records_path = ObjectStorageDetails(
+                json_data["recordFiles"][0]["bucket"],
+                json_data["recordFiles"][0]["namespace"],
+                json_data["recordFiles"][0]["path"],
+            ).path
+
         return Metadata(
             source_path=source_path,
             records_path=records_path,
@@ -69,19 +73,20 @@ class MetadataParser(Parser):
         json_data: dict
             dictionary format of the metadata jsonl file content.
         """
+
         def invalid_message(param):
-            return (f"The dataset metadata file is invalid. The field '{param}' is required but it is missing. "
+            return (
+                f"The dataset metadata file is invalid. The field '{param}' is required but it is missing. "
                 + "Update the metadata file or use the `DataLabeling.export()` method "
-                + "to create a new dataset metadata file.")
+                + "to create a new dataset metadata file."
+            )
 
         for k in MetadataParser.EXPECTED_KEYS:
             if k not in json_data:
-                raise ValueError(
-                    f"{invalid_message(k)}"
-                )
+                raise ValueError(f"{invalid_message(k)}")
         expected_list_format = ["labelsSet", "recordFiles"]
         for k in expected_list_format:
-            if not isinstance(json_data[k], list):
+            if k in json_data and not isinstance(json_data[k], list):
                 raise ValueError(f"{invalid_message(k)}")
         expected_dict_format = ["datasetSourceDetails", "datasetFormatDetails"]
         for k in expected_dict_format:
