@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 """
@@ -270,7 +270,7 @@ class LabeledDatasetReader:
         format: (str, optional). Defaults to None.
             Output format of annotations. Can be None, "spacy" or "yolo".
         chunksize: (int, optional). Defaults to None.
-            The amount of records that should be read in one iteration.
+            The number of records that should be read in one iteration.
             The result will be returned in a generator format.
 
         Returns
@@ -544,7 +544,6 @@ class ExportReader(Reader):
             The labeled dataset records.
         """
         metadata = self.info()
-
         if (
             format
             and isinstance(format, str)
@@ -560,7 +559,7 @@ class ExportReader(Reader):
             )
 
         records_reader = RecordReader.from_export_file(
-            path=metadata.records_path,
+            path=metadata.records_path or self.path,
             dataset_type=metadata.dataset_type,
             annotation_type=metadata.annotation_type,
             dataset_source_path=metadata.source_path,
@@ -570,5 +569,6 @@ class ExportReader(Reader):
             include_unlabeled=self.include_unlabeled,
             format=format,
             categories=metadata.labels,
+            includes_metadata=not metadata.records_path,
         )
         return records_reader.read()
