@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import os
@@ -21,6 +21,7 @@ from IPython.display import display
 from jinja2 import Environment, PackageLoader
 
 from ads.common import oci_client, auth, logger
+from ads.common.utils import FileOverwriteError
 
 from oci.data_flow.models import (
     CreateApplicationDetails,
@@ -150,7 +151,7 @@ class DataFlow:
 
         def show_in_notebook(app_self):
             """
-            Describe the project by showing it's properties
+            Describe the project by showing its properties
             """
             display(app_self)
 
@@ -186,7 +187,7 @@ class DataFlow:
         """
         Check if the parameters provided by users to create an application are
         valid and then prepare app_configuration for creating an app or saving
-         for future reuse.
+        for future reuse.
 
         Parameters
         ----------
@@ -609,26 +610,29 @@ class DataFlow:
         ----------
         app_config: dict
             the config file that contains all necessary parameters used to create a dataflow app
-
         overwrite_script: bool
             whether to overwrite the existing pyscript script on Object Storage
-
         overwrite_archive: bool
             whether to overwrite the existing archive file on Object Storage
 
         Returns
         -------
-        df_app: `oci.dataflow.models.Application`
+        df_app: oci.dataflow.models.Application
             New dataflow application.
         """
         #
         # upload pyspark_file_path to OCI object storage
         #
-        self._upload(
-            app_config["pyspark_file_path"],
-            app_config["script_bucket"],
-            overwrite=overwrite_script,
-        )
+        try:
+            self._upload(
+                app_config["pyspark_file_path"],
+                app_config["script_bucket"],
+                overwrite=overwrite_script,
+            )
+        except FileOverwriteError:
+            raise ValueError(
+                "You have a file with the same key in your bucket on object storage. Rename your file or set overwrite_script option to True."
+            )
         script_name = os.path.basename(app_config["pyspark_file_path"])
         file_uri = f'oci://{app_config["script_bucket"]}@{self.namespace}/{script_name}'
 
@@ -636,11 +640,16 @@ class DataFlow:
         if app_config["archive_path"] is None:
             return self._create_or_load_app(app_config, file_uri)
         else:
-            self._upload(
-                app_config["archive_path"],
-                app_config["archive_bucket"],
-                overwrite=overwrite_archive,
-            )
+            try:
+                self._upload(
+                    app_config["archive_path"],
+                    app_config["archive_bucket"],
+                    overwrite=overwrite_archive,
+                )
+            except FileOverwriteError:
+                raise ValueError(
+                    "You have a file with the same key in your bucket on object storage. Rename your file or set overwrite_archive option to True."
+                )
             archive_name = os.path.basename(app_config["archive_path"])
             archive_uri = (
                 f'oci://{app_config["archive_bucket"]}@{self.namespace}/{archive_name}'
@@ -669,9 +678,7 @@ class DataFlow:
         object_name = os.path.basename(local_path)
         if self._check_object_exist(object_name, bucket_name):
             if not overwrite:
-                raise ValueError(
-                    "You have a file with the same key in your bucket on object storage. Rename your file or set overwrite option to True."
-                )
+                raise FileOverwriteError()
             else:
                 logger.warning(
                     "You have a file with the same key in your bucket on object storage. It will be overwritten per your request."
@@ -695,7 +702,8 @@ class DataFlow:
 
         Returns
         -------
-        bool, whether the file already exists in the bucket in object storage
+        bool
+            whether the file already exists in the bucket in object storage
         """
         object_exist = self._check_object_exist_helper(
             object_name, bucket_name, start=None
@@ -729,7 +737,8 @@ class DataFlow:
 
         Returns
         -------
-        bool, whether the file already exists in the bucket in object storage
+        bool
+            whether the file already exists in the bucket in object storage
         """
         object_exist = False
         list_objects_response = self.object_storage_client.list_objects(
@@ -811,7 +820,7 @@ class DataFlow:
 
         Returns
         -------
-        app: `oci.dataflow.models.Application`
+        app: oci.dataflow.models.Application
             The oci.dataflow.models.Application with the matching ID.
         """
         if not app_id.startswith("ocid"):
@@ -848,7 +857,7 @@ class DataFlow:
 
         Returns
         -------
-        dfa: `ads.dataflow.dataflow.DataFlowApp`
+        dfa: ads.dataflow.dataflow.DataFlowApp
             A dataflow application of type ads.dataflow.dataflow.DataFlowApp
         """
 
@@ -990,10 +999,6 @@ class DataFlowApp(DataFlow):
         """
         Retrieve the app_config file used to create the data flow app
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
         app_config: Dict
@@ -1006,10 +1011,6 @@ class DataFlowApp(DataFlow):
         """
         Retrieve the oci link of the data flow app
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
         oci_link: str
@@ -1153,7 +1154,7 @@ class DataFlowApp(DataFlow):
         Parameters
         ----------
         run_config: dict, required
-            the config file that contains all necessary parameters used to create a dataflow run
+            The config file that contains all necessary parameters used to create a dataflow run
         save_log_to_local: bool, optional
             A boolean value that defaults to false. If set to true, it saves the log files to local dir
         copy_script_to_object_storage: bool, optional
@@ -1772,10 +1773,6 @@ class DataFlowLog:
         """
         Show all content of the log as the output of the notebook cell
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
         None
@@ -1788,10 +1785,6 @@ class DataFlowLog:
         """
         Get the path of the log file in object storage
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
         oci_path: str
@@ -1804,10 +1797,6 @@ class DataFlowLog:
         """
         Get the path of the log file in local directory
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
         local_path: str
@@ -1826,10 +1815,6 @@ class DataFlowLog:
         """
         Get the local directory where the log file is saved.
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
         local_dir: str
@@ -1876,13 +1861,9 @@ class DataFlowLog:
         Display the link of the log file to open in another tab of the jupyter
         environment.
 
-        Parameters
-        ----------
-        None
-
         Returns
         -------
-        link of the log file.
+        link of the log file
         """
         if self._local_path is None:
             return
