@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import pandas as pd
@@ -20,9 +20,9 @@ class ClassificationDataset(ADSDatasetWithTarget):
     Dataset for classification task
     """
 
-    def __init__(self, ddf, sampled_df, target, target_type, shape, **kwargs):
+    def __init__(self, df, sampled_df, target, target_type, shape, **kwargs):
         ADSDatasetWithTarget.__init__(
-            self, ddf, sampled_df, target, target_type, shape, **kwargs
+            self, df, sampled_df, target, target_type, shape, **kwargs
         )
 
     def auto_transform(
@@ -35,30 +35,32 @@ class ClassificationDataset(ADSDatasetWithTarget):
         """
         Return transformed dataset with several optimizations applied automatically.
         The optimizations include:
-           - Dropping constant and primary key columns, which has no predictive quality.
-           - Imputation, to fill in missing values in noisy data.
-                - For continuous variables, fill with mean if less than 40% is missing, else drop.
-                - For categorical variables, fill with most frequent if less than 40% is missing, else drop.
-           - Dropping strongly co-correlated columns that tend to produce less generalizable models.
-           - Balancing dataset using up or down sampling.
+
+        - Dropping constant and primary key columns, which has no predictive quality,
+        - Imputation, to fill in missing values in noisy data:
+
+            - For continuous variables, fill with mean if less than 40% is missing, else drop,
+            - For categorical variables, fill with most frequent if less than 40% is missing, else drop,
+
+        - Dropping strongly co-correlated columns that tend to produce less generalizable models,
+        - Balancing dataset using up or down sampling.
 
         Parameters
         ----------
         fix_imbalance : bool, defaults to True.
             Fix imbalance between classes in dataset. Used only for classification datasets.
-
         correlation_threshold: float, defaults to 0.7. It must be between 0 and 1, inclusive.
             The correlation threshold where columns with correlation higher than the threshold will
             be considered as strongly co-correlated and recommended to be taken care of.
-
         frac: float, defaults to 1.0. Range -> (0, 1].
             What fraction of the data should be used in the calculation?
-
         correlation_methods: Union[list, str], defaults to 'pearson'.
-            'pearson': Use Pearson's Correlation between continuous features.
-            'cramers v': Use Cramer's V correlations between categorical features.
-            'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features.
-            'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+
             Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
 
         Returns
@@ -68,7 +70,7 @@ class ClassificationDataset(ADSDatasetWithTarget):
 
         Examples
         --------
-        ds_clean = ds.auto_transform(correlation_threshold=0.6)
+        >>> ds_clean = ds.auto_transform(correlation_threshold=0.6)
         """
         frac = deprecate_default_value(
             frac,
@@ -78,7 +80,7 @@ class ClassificationDataset(ADSDatasetWithTarget):
             FutureWarning,
         )
         with utils.get_progress_bar(7) as progress:
-            ddf, sampled_df, transformer_pipeline = self._transform(
+            df, sampled_df, transformer_pipeline = self._transform(
                 progress=progress,
                 fix_imbalance=fix_imbalance,
                 correlation_threshold=correlation_threshold,
@@ -86,13 +88,13 @@ class ClassificationDataset(ADSDatasetWithTarget):
                 correlation_methods=correlation_methods,
             )
             return self._build_new_dataset(
-                ddf,
+                df,
                 sampled_df=sampled_df,
                 transformers=transformer_pipeline.steps,
                 progress=progress,
             )
 
-    def convert_to_text_classification(self, text_column):
+    def convert_to_text_classification(self, text_column: str):
         """
         Builds a new dataset with the given text column as the only feature besides target.
 
@@ -105,11 +107,11 @@ class ClassificationDataset(ADSDatasetWithTarget):
         -------
         ds: TextClassificationDataset
             Dataset with one text feature and a classification target
+
         Examples
         --------
-        review_ds = DatasetFactory.open("review_data.csv")
-
-        ds_text_class = review_ds.convert_to_text_classification('reviews')
+        >>> review_ds = DatasetFactory.open("review_data.csv")
+        >>> ds_text_class = review_ds.convert_to_text_classification('reviews')
         """
 
         def _select_features(df, feature_names, target):
@@ -118,7 +120,7 @@ class ClassificationDataset(ADSDatasetWithTarget):
             return df[feature_names]
 
         transformer = (
-            "convert_to_text_classification using feature %s".format(text_column),
+            f"convert_to_text_classification using feature {text_column}",
             FunctionTransformer(
                 func=_select_features,
                 validate=False,
@@ -130,21 +132,21 @@ class ClassificationDataset(ADSDatasetWithTarget):
         )
         if utils.is_same_class(self, BinaryClassificationDataset):
             new_ds = BinaryTextClassificationDataset(
-                self.ddf[[self.target.name, text_column]],
+                self.df[[self.target.name, text_column]],
                 self.sampled_df[[self.target.name, text_column]],
                 self.target.name,
                 self.target.type,
-                (len(self.ddf), 2),
+                (len(self.df), 2),
                 **self.init_kwargs,
             )
 
         else:
             new_ds = MultiClassTextClassificationDataset(
-                self.ddf[[self.target.name, text_column]],
+                self.df[[self.target.name, text_column]],
                 self.sampled_df[[self.target.name, text_column]],
                 self.target.name,
                 self.target.type,
-                (len(self.ddf), 2),
+                (len(self.df), 2),
                 **self.init_kwargs,
             )
         new_ds.transformer_pipeline = self._update_transformer_pipeline(transformer)
@@ -157,8 +159,7 @@ class ClassificationDataset(ADSDatasetWithTarget):
         Parameters
         ----------
         sampler: An instance of SamplerMixin
-            Should implement fit_resample(X,y) method
-            If None, does random down sampling
+            Should implement fit_resample(X,y) method. If None, does random down sampling.
 
         Returns
         -------
@@ -167,17 +168,16 @@ class ClassificationDataset(ADSDatasetWithTarget):
 
         Examples
         --------
-        ds = DatasetFactory.open("some_data.csv")
-
-        ds_balanced_small = ds.down_sample()
+        >>> ds = DatasetFactory.open("some_data.csv")
+        >>> ds_balanced_small = ds.down_sample()
         """
         return self._build_new_dataset(
-            helper.down_sample(self.ddf, self.target.name)
+            helper.down_sample(self.df, self.target.name)
             if sampler is None
             else helper.sample(
                 sampler,
-                self.ddf.drop(self.target.name, axis=1),
-                self.ddf[self.target.name],
+                self.df.drop(self.target.name, axis=1),
+                self.df[self.target.name],
             )
         )
 
@@ -188,9 +188,10 @@ class ClassificationDataset(ADSDatasetWithTarget):
         Parameters
         ----------
         sampler: An instance of SamplerMixin
-            Should implement fit_resample(X,y) method
+            Should implement fit_resample(X,y) method.
             If 'default', either SMOTE or random sampler will be used
-        fill_missing_type: a string, can either be 'mean', 'mode' or 'median'
+        fill_missing_type: a string
+            Can either be 'mean', 'mode' or 'median'.
 
         Returns
         -------
@@ -199,13 +200,12 @@ class ClassificationDataset(ADSDatasetWithTarget):
 
         Examples
         --------
-        ds = DatasetFactory.open("some_data.csv")
-
-        ds_balanced_large = ds.up_sample()
+        >>> ds = DatasetFactory.open("some_data.csv")
+        >>> ds_balanced_large = ds.up_sample()
         """
         return self._build_new_dataset(
             helper.up_sample(
-                self.ddf,
+                self.df,
                 self.target.name,
                 sampler=sampler,
                 feature_types=self.feature_types,
@@ -219,7 +219,7 @@ class BinaryClassificationDataset(ClassificationDataset):
     """
 
     def __init__(
-        self, ddf, sampled_df, target, target_type, shape, positive_class=None, **kwargs
+        self, df, sampled_df, target, target_type, shape, positive_class=None, **kwargs
     ):
         if positive_class is not None:
             # map positive_class to True
@@ -229,10 +229,10 @@ class BinaryClassificationDataset(ClassificationDataset):
                 df[column_name] = df[column_name].map(arg)
                 return df
 
-            ddf = ddf.map_partitions(mapper, target, update_arg)
+            df = df.map_partitions(mapper, target, update_arg)
             sampled_df = mapper(sampled_df, target, update_arg)
         ClassificationDataset.__init__(
-            self, ddf, sampled_df, target, target_type, shape, **kwargs
+            self, df, sampled_df, target, target_type, shape, **kwargs
         )
 
     def set_positive_class(self, positive_class, missing_value=False):
@@ -258,11 +258,9 @@ class BinaryClassificationDataset(ClassificationDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("iris.csv")
-
-        ds_with_target = ds.set_target('class')
-
-        ds_with_pos_class = ds.set_positive_class('setosa')
+        >>> ds = DatasetFactory.open("iris.csv")
+        >>> ds_with_target = ds.set_target('class')
+        >>> ds_with_pos_class = ds.set_positive_class('setosa')
         """
         if positive_class not in self.target.target_vals:
             raise ValidationError(
@@ -281,9 +279,9 @@ class MultiClassClassificationDataset(ClassificationDataset):
     Dataset for multi-class classification
     """
 
-    def __init__(self, ddf, sampled_df, target, target_type, shape, **kwargs):
+    def __init__(self, df, sampled_df, target, target_type, shape, **kwargs):
         ClassificationDataset.__init__(
-            self, ddf, sampled_df, target, target_type, shape, **kwargs
+            self, df, sampled_df, target, target_type, shape, **kwargs
         )
 
 
@@ -292,9 +290,9 @@ class BinaryTextClassificationDataset(BinaryClassificationDataset):
     Dataset for binary text classification
     """
 
-    def __init__(self, ddf, sampled_df, target, target_type, shape, **kwargs):
+    def __init__(self, df, sampled_df, target, target_type, shape, **kwargs):
         BinaryClassificationDataset.__init__(
-            self, ddf, sampled_df, target, target_type, shape, **kwargs
+            self, df, sampled_df, target, target_type, shape, **kwargs
         )
 
     def auto_transform(self):
@@ -319,9 +317,9 @@ class MultiClassTextClassificationDataset(MultiClassClassificationDataset):
     Dataset for multi-class text classification
     """
 
-    def __init__(self, ddf, sampled_df, target, target_type, shape, **kwargs):
+    def __init__(self, df, sampled_df, target, target_type, shape, **kwargs):
         MultiClassClassificationDataset.__init__(
-            self, ddf, sampled_df, target, target_type, shape, **kwargs
+            self, df, sampled_df, target, target_type, shape, **kwargs
         )
 
     def auto_transform(self):
