@@ -1,7 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: utf-8; -*-
+# -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import, division
@@ -47,6 +47,7 @@ from ads.dataset.correlation import (
     _get_columns_by_type,
     _validate_correlation_methods,
 )
+from ads.common.runtime_dependency import runtime_dependency
 
 N_Features_Wide_Dataset = 64
 
@@ -132,10 +133,10 @@ class ADSDataset(PandasDataset):
     def __len__(self):
         return self.shape[0]
 
+    @property
     @deprecated(
         "2.5.2", details="The ddf attribute is deprecated. Use the df attribute."
     )
-    @property
     def ddf(self):
         return self.df
 
@@ -145,13 +146,10 @@ class ADSDataset(PandasDataset):
     def compute(self):
         return self.df
 
+    @runtime_dependency(
+        module="ipywidgets", object="HTML", install_from="oracle-ads[notebook]"
+    )
     def _repr_html_(self):
-        try:
-            from ipywidgets import HTML
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
-            raise e
-
         display(
             HTML(
                 utils.horizontal_scrollable_div(
@@ -180,9 +178,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("classfication_data.csv")
-
-        ds.head()
+        >>> ds = DatasetFactory.open("classfication_data.csv")
+        >>> ds.head()
         * displays the first 5 rows of the dataset, just as the traditional head() function would *
         """
         df = self.df.head(n=n)
@@ -201,14 +198,8 @@ class ADSDataset(PandasDataset):
             def _constructor(self):
                 return FormattedDataFrame
 
+            @runtime_dependency(module="ipywidgets", object="HTML")
             def _repr_html_(self):
-
-                try:
-                    from ipywidgets import HTML
-                except ModuleNotFoundError as e:
-                    utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
-                    raise e
-
                 display(
                     HTML(
                         utils.horizontal_scrollable_div(
@@ -227,11 +218,11 @@ class ADSDataset(PandasDataset):
         return FormattedDataFrame(df)
 
     def call(self, func, *args, sample_size=None, **kwargs):
-        """
+        r"""
         Runs a custom function on dataframe
 
-        func will receive the pandas dataframe(which represents the dataset) as an argument named 'df' by default.
-        This can be overridden by specifying the dataframe argument name in a tuple (func, dataframe_name)
+        func will receive the pandas dataframe (which represents the dataset) as an argument named 'df' by default.
+        This can be overridden by specifying the dataframe argument name in a tuple (func, dataframe_name).
 
         Parameters
         ----------
@@ -243,20 +234,20 @@ class ADSDataset(PandasDataset):
             Positional arguments passed into func
         sample_size: int, Optional
             To use a sampled dataframe
-        **kwargs: mapping, optional
+        kwargs: mapping, optional
             A dictionary of keyword arguments passed into func
+
         Returns
         -------
         func: function
-            a plotting function that contains *args and **kwargs
+            a plotting function that contains `*args` and `**kwargs`
 
         Examples
         --------
-        ds = DatasetFactory.open("classfication_data.csv")
-
-        def f1(df):
-            return(sum(df), axis=0)
-        sum_ds = ds.call(f1)
+        >>> ds = DatasetFactory.open("classfication_data.csv")
+        >>> def f1(df):
+        ...  return(sum(df), axis=0)
+        >>> sum_ds = ds.call(f1)
         """
 
         data = "df"
@@ -286,8 +277,7 @@ class ADSDataset(PandasDataset):
         type_discovery: bool
             This is set as True by default.
         target_type: type
-            If provided, then the target will be typed with the
-                     provided value.
+            If provided, then the target will be typed with the provided value.
 
         Returns
         -------
@@ -296,9 +286,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("classfication_data.csv")
-
-        ds_with_target= ds.set_target("target_class")
+        >>> ds = DatasetFactory.open("classfication_data.csv")
+        >>> ds_with_target= ds.set_target("target_class")
         """
         from ads.dataset.factory import DatasetFactory
 
@@ -338,7 +327,7 @@ class ADSDataset(PandasDataset):
         filter: str, optional
             The query string to filter the dataframe, for example
             ds.to_pandas(filter="age > 50 and location == 'san francisco")
-            See also: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
+            See also https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
         frac: float, optional
             fraction of original data to return.
         include_transformer_pipeline: bool, default: False
@@ -353,13 +342,12 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_as_df = ds.to_pandas()
 
-        ds_as_df = ds.to_pandas()
-
-        See also:
-
-        https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
+        Notes
+        -----
+        See also https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
         """
         df = self.df.query(filter) if filter is not None else self.df.copy()
         if frac is not None:
@@ -385,6 +373,7 @@ class ADSDataset(PandasDataset):
             include_transformer_pipeline=include_transformer_pipeline,
         )
 
+    @runtime_dependency(module="dask.dataframe", short_name="dd")
     def to_dask(
         self,
         filter=None,
@@ -404,7 +393,7 @@ class ADSDataset(PandasDataset):
         filter: str, optional
             The query string to filter the dataframe, for example
             ds.to_dask(filter="age > 50 and location == 'san francisco")
-            See also: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
+            See also https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
         frac: float, optional
             fraction of original data to return.
         include_transformer_pipeline: bool, default: False
@@ -419,21 +408,15 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_dask = ds.to_dask()
-
-        See also:
-
-        http://docs.dask.org/en/latest/dataframe-api.html#dataframe
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_dask = ds.to_dask()
 
+        Notes
+        -----
+        See also http://docs.dask.org/en/latest/dataframe-api.html#dataframe and
         https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
+
         """
-        try:
-            import dask.dataframe as dd
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("dask", "dask")
-            raise e
         res = self.to_pandas(
             filter=filter,
             frac=frac,
@@ -455,6 +438,7 @@ class ADSDataset(PandasDataset):
             include_transformer_pipeline=include_transformer_pipeline,
         )
 
+    @runtime_dependency(module="h2o")
     def to_h2o(self, filter=None, frac=None, include_transformer_pipeline=False):
         """
         Returns a copy of the data as h2o.H2OFrame, and a sklearn pipeline optionally that holds the
@@ -468,7 +452,7 @@ class ADSDataset(PandasDataset):
         filter: str, optional
             The query string to filter the dataframe, for example
             ds.to_h2o(filter="age > 50 and location == 'san francisco")
-            See also: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
+            See also https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
         frac: float, optional
             fraction of original data to return.
         include_transformer_pipeline: bool, default: False
@@ -483,19 +467,13 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_as_h2o = ds.to_h2o()
 
-        ds_as_h2o = ds.to_h2o()
-
-        See also:
-        https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
+        Notes
+        -----
+        See also https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
         """
-        try:
-            import h2o
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("h2o", "h2o")
-            raise e
-
         res = self.to_pandas(
             filter=filter,
             frac=frac,
@@ -517,6 +495,7 @@ class ADSDataset(PandasDataset):
             include_transformer_pipeline=include_transformer_pipeline,
         )
 
+    @runtime_dependency(module="xgboost", install_from="oracle-ads[boosted]")
     def to_xgb(self, filter=None, frac=None, include_transformer_pipeline=False):
         """
         Returns a copy of the data as xgboost.DMatrix, and a sklearn pipeline optionally that holds the
@@ -530,7 +509,7 @@ class ADSDataset(PandasDataset):
         filter: str, optional
             The query string to filter the dataframe, for example
             ds.to_xgb(filter="age > 50 and location == 'san francisco")
-            See also: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
+            See also https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
         frac: float, optional
             fraction of original data to return.
         include_transformer_pipeline: bool, default: False
@@ -545,18 +524,13 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> xgb_dmat = ds.to_xgb()
 
-        xgb_dmat = ds.to_xgb()
-
-        See also:
-        https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
+        Notes
+        -----
+        See also https://scikit-learn.org/stable/modules/generated/sklearn.pipeline.Pipeline.html#sklearn.pipeline.Pipeline
         """
-        try:
-            import xgboost
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("xgboost", "ads[boosted]")
-            raise e
         res = self.to_pandas(
             filter=filter,
             frac=frac,
@@ -589,9 +563,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_sample = ds.sample()
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_sample = ds.sample()
         """
         df = self.df.sample(frac=frac, random_state=random_state)
         return self._build_new_dataset(df)
@@ -617,9 +590,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_smaller = ds.drop_columns(['col1', 'col2'])
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_smaller = ds.drop_columns(['col1', 'col2'])
         """
         self._validate_feature(columns)
         return self.drop(columns, axis=1)
@@ -629,7 +601,7 @@ class ADSDataset(PandasDataset):
         Return new dataset with new column or values of the existing column mapped according to input correspondence.
 
         Used for adding a new column or substituting each value in a column with another value, that may be derived from
-         a function, a :class:`pandas.Series` or a :class:`pandas.DataFrame` .
+        a function, a :class:`pandas.Series` or a :class:`pandas.DataFrame`.
 
         Parameters
         ----------
@@ -645,11 +617,9 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_same_size = ds.assign_column('target',lambda x:  x>15 if x not None)
-
-        ds_bigger = ds.assign_column('new_col', np.arange(ds.shape[0]))
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_same_size = ds.assign_column('target',lambda x:  x>15 if x not None)
+        >>> ds_bigger = ds.assign_column('new_col', np.arange(ds.shape[0]))
         """
         target_name = (
             self.target.name if not utils.is_same_class(self, ADSDataset) else None
@@ -722,9 +692,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_renamed = ds.rename_columns({'col1': 'target'})
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_renamed = ds.rename_columns({'col1': 'target'})
         """
         if isinstance(columns, list):
             assert len(columns) == len(
@@ -743,13 +712,12 @@ class ADSDataset(PandasDataset):
         Parameters
         ----------
         name: str
-              Name of the dataset.
+            Name of the dataset.
 
         Examples
         --------
-        ds = DatasetFactory.open("data1.csv")
-
-        ds_renamed = ds.set_name("dataset1")
+        >>> ds = DatasetFactory.open("data1.csv")
+        >>> ds_renamed = ds.set_name("dataset1")
         """
         self.name = name
 
@@ -762,13 +730,12 @@ class ADSDataset(PandasDataset):
         Parameters
         ----------
         description: str
-              Description of the dataset.
+            Description of the dataset.
 
         Examples
         --------
-        ds = DatasetFactory.open("data1.csv")
-
-        ds_renamed = ds.set_description("dataset1 is from "data1.csv"")
+        >>> ds = DatasetFactory.open("data1.csv")
+        >>> ds_renamed = ds.set_description("dataset1 is from "data1.csv"")
         """
         self.description = description
 
@@ -790,8 +757,8 @@ class ADSDataset(PandasDataset):
             Name to uniquely identify the snapshot using DatasetFactory.list_snapshots().
             If not provided, an auto-generated name is used.
         storage_options: dict, optional
-             Parameters passed on to the backend filesystem class.
-             Defaults to storage_options set using DatasetFactory.set_default_storage().
+            Parameters passed on to the backend filesystem class.
+            Defaults to storage_options set using DatasetFactory.set_default_storage().
 
         Returns
         -------
@@ -800,9 +767,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_uri = ds.snapshot()
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_uri = ds.snapshot()
         """
         if snapshot_dir is None:
             import ads.dataset.factory as factory
@@ -844,8 +810,8 @@ class ADSDataset(PandasDataset):
         ----------
         path: str
             Location to write to. If there are more than one partitions in df, should include a glob character to
-            expand into a set of file names, or provide a ``name_function=`` parameter.
-            Supports protocol specifications such as ``"oci://"`, `"s3://"``.
+            expand into a set of file names, or provide a `name_function=parameter`.
+            Supports protocol specifications such as `"oci://"`, `"s3://"`.
         storage_options: dict, optional
              Parameters passed on to the backend filesystem class.
              Defaults to storage_options set using DatasetFactory.set_default_storage().
@@ -853,9 +819,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        [ds_link] = ds.to_csv("my/path.csv")
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> [ds_link] = ds.to_csv("my/path.csv")
         """
         if storage_options is None:
             import ads.dataset.factory as factory
@@ -872,8 +837,8 @@ class ADSDataset(PandasDataset):
         ----------
         path: str
             Location to write to. If there are more than one partitions in df, should include a glob character to
-            expand into a set of file names, or provide a ``name_function=`` parameter.
-            Supports protocol specifications such as ``"oci://"`, `"s3://"``.
+            expand into a set of file names, or provide a `name_function=parameter`.
+            Supports protocol specifications such as `"oci://"`, `"s3://"`.
         storage_options: dict, optional
              Parameters passed on to the backend filesystem class.
              Defaults to storage_options set using DatasetFactory.set_default_storage().
@@ -881,9 +846,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds.to_parquet("my/path")
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds.to_parquet("my/path")
         """
         if storage_options is None:
             import ads.dataset.factory as factory
@@ -894,24 +858,23 @@ class ADSDataset(PandasDataset):
 
     def to_json(self, path, storage_options=None, **kwargs):
         """
-         Save data to JSON files.
+        Save data to JSON files.
 
-         Parameters
-         ----------
+        Parameters
+        ----------
         path: str
-             Location to write to. If there are more than one partitions in df, should include a glob character to
-             expand into a set of file names, or provide a ``name_function=`` parameter.
-             Supports protocol specifications such as ``"oci://"`, `"s3://"``
-         storage_options: dict, optional
-              Parameters passed on to the backend filesystem class.
-              Defaults to storage_options set using DatasetFactory.set_default_storage().
-         kwargs: dict, optional
+            Location to write to. If there are more than one partitions in df, should include a glob character to
+            expand into a set of file names, or provide a `name_function=parameter`.
+            Supports protocol specifications such as `"oci://"`, `"s3://"`.
+        storage_options: dict, optional
+            Parameters passed on to the backend filesystem class.
+            Defaults to storage_options set using DatasetFactory.set_default_storage().
+        kwargs: dict, optional
 
-         Examples
-         --------
-         ds = DatasetFactory.open("data.csv")
-
-         ds.to_json("my/path.json")
+        Examples
+        --------
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds.to_json("my/path.json")
         """
         if storage_options is None:
             import ads.dataset.factory as factory
@@ -921,26 +884,32 @@ class ADSDataset(PandasDataset):
 
         return self.df.to_json(path, storage_options=storage_options, **kwargs)
 
-    def to_hdf(self, path, key, storage_options=None, **kwargs):
+    def to_hdf(
+        self, path: str, key: str, storage_options: dict = None, **kwargs
+    ) -> str:
         """
         Save data to Hierarchical Data Format (HDF) files.
 
         Parameters
         ----------
         path : string
-            Path to a target filename.  May contain a ``*`` to denote many filenames.
+            Path to a target filename.
         key : string
-            Datapath within the files.  May contain a ``*`` to denote many locations.
+            Datapath within the files.
         storage_options: dict, optional
             Parameters passed to the backend filesystem class.
             Defaults to storage_options set using DatasetFactory.set_default_storage().
         kwargs: dict, optional
 
+        Returns
+        -------
+        str
+            The filename of the HDF5 file created.
+
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds.to_hdf("my/path.h5")
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds.to_hdf(path="my/path.h5", key=)
         """
         if storage_options is None:
             import ads.dataset.factory as factory
@@ -948,11 +917,32 @@ class ADSDataset(PandasDataset):
             storage_options = factory.default_storage_options
             logger.info("Using default storage options")
 
-        return self.df.to_hdf(path, key, storage_options=storage_options, **kwargs)
+        with pd.HDFStore(
+            "memory",
+            mode="w",
+            driver="H5FD_CORE",
+            driver_core_backing_store=0,
+        ) as hdf_store:
+            hdf_store.put(key, self.df, format=kwargs.get("hdf5_format", "fixed"))
+            data = hdf_store._handle.get_file_image()
 
+        new_path = (
+            path.replace("*", "0")
+            if path[-3:] == ".h5"
+            else path.replace("*", "0") + ".h5"
+        )
+
+        with fsspec.open(
+            urlpath=new_path, mode="wb", storage_options=storage_options, **kwargs
+        ) as fo:
+            fo.write(data)
+
+        return new_path
+
+    @runtime_dependency(module="fastavro", install_from="oracle-ads[data]")
     def to_avro(self, path, schema=None, storage_options=None, **kwargs):
         """
-        Save data to Avro files
+        Save data to Avro files.
         Avro is a remote procedure call and data serialization framework developed within Apache's Hadoop project. It
         uses JSON for defining data types and protocols, and serializes data in a compact binary format.
 
@@ -968,40 +958,33 @@ class ADSDataset(PandasDataset):
         kwargs: dict, optional
             See https://fastavro.readthedocs.io/en/latest/writer.html
 
-        Avro schema dictionary
-        ----------------------
-            The schema is a complex dictionary describing the data, see
-        https://avro.apache.org/docs/1.8.2/gettingstartedpython.html#Defining+a+schema
-        and https://fastavro.readthedocs.io/en/latest/writer.html .
-        It's structure is as follows::
+        Notes
+        -----
+        Avro schema is a complex dictionary describing the data,
+        see https://avro.apache.org/docs/1.8.2/gettingstartedpython.html#Defining+a+schema
+        and https://fastavro.readthedocs.io/en/latest/writer.html.
+        Its structure is as follows::
+
             {'name': 'Test',
-             'namespace': 'Test',
-             'doc': 'Descriptive text',
-             'type': 'record',
-             'fields': [
+            'namespace': 'Test',
+            'doc': 'Descriptive text',
+            'type': 'record',
+            'fields': [
                 {'name': 'a', 'type': 'int'},
-             ]}
+            ]}
+
         where the "name" field is required, but "namespace" and "doc" are optional
         descriptors; "type" must always be "record". The list of fields should
         have an entry for every key of the input records, and the types are
         like the primitive, complex or logical types of the Avro spec
-        ( https://avro.apache.org/docs/1.8.2/spec.html ).
+        (https://avro.apache.org/docs/1.8.2/spec.html).
 
         Examples
         --------
-        ds = DatasetFactory.open("data.avro")
-
-        ds.to_avro("my/path.avro")
+        >>> ds = DatasetFactory.open("data.avro")
+        >>> ds.to_avro("my/path.avro")
         """
         # Get the row by row formatting
-
-        try:
-            from fastavro import writer as avro_writer
-            from fastavro import parse_schema as avro_parse_schema
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("fastavro", "oracle-ads[data]")
-            raise e
-
         data_row_by_row = []
         for i, row in self.df.iterrows():
             data_row_by_row.append(row.to_dict())
@@ -1015,7 +998,7 @@ class ADSDataset(PandasDataset):
                 fields.append({"name": col, "type": ["null", dtype]})
             schema["fields"] = fields
 
-        parsed_schema = avro_parse_schema(schema=schema)
+        parsed_schema = fastavro.parse_schema(schema=schema)
         new_path = (
             path.replace("*", "0")
             if path[-5:] == ".avro"
@@ -1024,7 +1007,7 @@ class ADSDataset(PandasDataset):
         with fsspec.open(
             new_path, "wb", storage_options=storage_options, **kwargs
         ) as fo:
-            avro_writer(fo, parsed_schema, data_row_by_row)
+            fastavro.writer(fo, parsed_schema, data_row_by_row)
         return new_path
 
     def _convert_dtypes_to_avro_types(self):
@@ -1055,7 +1038,7 @@ class ADSDataset(PandasDataset):
             key is the existing feature name
             value is the data type to which the values of the feature should be converted.
             Valid data types: All numpy datatypes (Example: np.float64, np.int64, ...)
-                or one of categorical, continuous, ordinal or datetime.
+            or one of categorical, continuous, ordinal or datetime.
 
         Returns
         -------
@@ -1064,9 +1047,8 @@ class ADSDataset(PandasDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        ds_reformatted = ds.astype({"target": "categorical"})
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> ds_reformatted = ds.astype({"target": "categorical"})
         """
         return self.__getattr__("astype")(helper.map_types(types))
 
@@ -1079,16 +1061,13 @@ class ADSDataset(PandasDataset):
         data : Union[ADSDataset, pandas.DataFrame]
             Data to merge.
         kwargs : dict, optional
-            kwargs: additional keyword arguments that would be passed to underlying dataframe's merge API.
-            supported.
+            additional keyword arguments that would be passed to underlying dataframe's merge API.
 
         Examples
         --------
-        ds1 = DatasetFactory.open("data1.csv")
-
-        ds2 = DatasetFactory.open("data2.csv")
-
-        ds_12 = ds1.merge(ds2)
+        >>> ds1 = DatasetFactory.open("data1.csv")
+        >>> ds2 = DatasetFactory.open("data2.csv")
+        >>> ds_12 = ds1.merge(ds2)
         """
         assert isinstance(data, pd.DataFrame) or isinstance(
             data, ADSDataset
@@ -1319,27 +1298,27 @@ class ADSDataset(PandasDataset):
 
         Parameters
         ----------
-        correlation_methods: Union[list, str], default to 'pearson'.
-            'pearson': Use Pearson's Correlation between continuous features.
-            'cramers v': Use Cramer's V correlations between categorical features.
-            'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features.
-            'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+        correlation_methods: Union[list, str], default to 'pearson'
+
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+
             Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
-
-        frac: Is deprecated and replaced by sample_size.
-
-        sample_size: float, defaults to 1.0. Float, Range -> (0, 1].
+        frac:
+            Is deprecated and replaced by sample_size.
+        sample_size: float, defaults to 1.0. Float, Range -> (0, 1]
             What fraction of the data should be used in the calculation?
-
-        nan_threshold: float, default to 0.8, Range -> [0, 1].
+        nan_threshold: float, default to 0.8, Range -> [0, 1]
             Only compute a correlation when the proportion of the values, in a column, is less than or equal to nan_threshold.
+        overwrite:
+            Is deprecated and replaced by force_recompute.
+        force_recompute: bool, default to be False
 
-        overwrite: Is deprecated and replaced by force_recompute.
-
-        force_recompute: bool, default to be False.
-            If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
-            it returns the cached correlation matrix.
-            If True, it calculates the correlation matrix regardless whether there is cached result or not.
+            - If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
+              it returns the cached correlation matrix.
+            - If True, it calculates the correlation matrix regardless whether there is cached result or not.
 
         Returns
         -------
@@ -1564,45 +1543,42 @@ class ADSDataset(PandasDataset):
         80% of NA/null values. By default, only 'pearson' correlation is calculated and shown in the first tab.
         Set correlation_methods='all' to show all correlation charts.
 
-           Parameters
-           ----------
-           frac: Is superseded by sample_size.
+        Parameters
+        ----------
+        frac: Is superseded by sample_size
+        sample_size: float, defaults to 1.0. Float, Range -> (0, 1]
+            What fraction of the data should be used in the calculation?
+        nan_threshold: float, defaults to 0.8, Range -> [0, 1]
+            In the default case, it will only calculate the correlation of the columns which has less than or equal to
+            80% of missing values.
+        overwrite:
+            Is deprecated and replaced by force_recompute.
+        force_recompute: bool, default to be False.
 
-           sample_size: float, defaults to 1.0. Float, Range -> (0, 1].
-                What fraction of the data should be used in the calculation?
+            - If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
+              it returns the cached correlation matrix.
+            - If True, it calculates the correlation matrix regardless whether there is cached result or not.
 
-           nan_threshold: float, defaults to 0.8, Range -> [0, 1].
-                In the default case, it will only calculate the correlation of the columns which has less than or equal to
-                80% of missing values.
+        plot_type: str, default to "heatmap"
+            It can only be "heatmap" or "bar". Note that if "bar" is chosen, correlation_target also has to be set and
+            the bar chart will only show the correlation values of the pairs which have the target in them.
+        correlation_target: str, default to Non
+            It can be any columns of type continuous, ordinal, categorical or zipcode. When correlation_target is set,
+            only pairs that contains correlation_target will show.
+        correlation_threshold: float, default to -1
+            It can be any number between -1 and 1.
+        correlation_methods: Union[list, str], defaults to 'pearson'
 
-           overwrite: Is deprecated and replaced by force_recompute.
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
 
-           force_recompute: bool, default to be False.
-                If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
-                it returns the cached correlation matrix.
-                If True, it calculates the correlation matrix regardless whether there is cached result or not.
+            Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
 
-           plot_type: str, default to "heatmap".
-                It can only be "heatmap" or "bar". Note that if "bar" is chosen, correlation_target also has to be set and
-                the bar chart will only show the correlation values of the pairs which have the target in them.
-
-           correlation_target: str, default to None.
-                It can be any columns of type continuous, ordinal, categorical or zipcode. When correlation_target is set,
-                only pairs that contains correlation_target will show.
-
-           correlation_threshold: float, default to -1.
-                It can be any number between -1 and 1.
-
-            correlation_methods: Union[list, str], defaults to 'pearson'.
-                'pearson': Use Pearson's Correlation between continuous features.
-                'cramers v': Use Cramer's V correlations between categorical features.
-                'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features.
-                'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
-                Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
-
-           Returns
-           -------
-           None.
+        Returns
+        -------
+        None
         """
         frac = deprecate_default_value(
             frac,
@@ -1660,6 +1636,9 @@ class ADSDataset(PandasDataset):
             **kwargs,
         )
 
+    @runtime_dependency(
+        module="ipywidgets.widgets", install_from="oracle-ads[notebook]"
+    )
     def show_in_notebook(
         self,
         correlation_threshold=-1,
@@ -1671,43 +1650,41 @@ class ADSDataset(PandasDataset):
     ):
         """
         Provide visualization of dataset.
-        - Display feature distribution: The data table display will show a maximum of 8 digits.
+
+        - Display feature distribution. The data table display will show a maximum of 8 digits,
         - Plot the correlation between the dataset features (as a heatmap) only when all the features are
-        continuous or ordinal.
+          continuous or ordinal,
         - Display data head.
-            Parameters
-            ----------
-            correlation_threshold : int, default -1
-                The correlation threshold to select, which only show features that have larger or equal
-                correlation values than the threshold.
-            selected_index: int, str, default 0
-                The displayed output is stacked into an accordion widget, use selected_index to force the display to open
-                a specific element, use the (zero offset) index or any prefix string of the name (eg, 'corr' for
-                correlations)
-            sample_size: int, default 0
-                The size (in rows) to sample for visualizations
-            visualize_features: bool default False
-                For the "Features" section control if feature visualizations are shown or not. If not only
-                a summary of the numeric statistics is shown. The numeric statistics are also always shows
-                for wide (>64 features) datasets
-            correlation_methods: Union[list, str], default to 'pearson'.
-                'pearson': Use Pearson's Correlation between continuous features.
-                'cramers v': Use Cramer's V correlations between categorical features
-                'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features
-                'all' is equivalent to ['pearson', 'cramers v', 'correlation ratio']
-                Or a list containing any combination of these methods, for example, ['pearson', 'cramers v']
+
+        Parameters
+        ----------
+        correlation_threshold : int, default -1
+            The correlation threshold to select, which only show features that have larger or equal
+            correlation values than the threshold.
+        selected_index: int, str, default 0
+            The displayed output is stacked into an accordion widget, use selected_index to force the display to open
+            a specific element, use the (zero offset) index or any prefix string of the name (eg, 'corr' for
+            correlations)
+        sample_size: int, default 0
+            The size (in rows) to sample for visualizations
+        visualize_features: bool default False
+            For the "Features" section control if feature visualizations are shown or not. If not only
+            a summary of the numeric statistics is shown. The numeric statistics are also always shows
+            for wide (>64 features) datasets
+        correlation_methods: Union[list, str], default to 'pearson'
+
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+
+            Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
         """
 
         if not utils.is_notebook():
             print("show_in_notebook called but not in notebook environment")
             return
 
-        try:
-            from ipywidgets import widgets, HTML, HBox, VBox, Box, Layout, Label
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
-            raise e
-
         n_rows, n_columns = self.shape
 
         min_sample_size = 10000
