@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 
@@ -313,7 +313,7 @@ class SeabornDatasets(DatasetBrowser):
 
 class SklearnDatasets(DatasetBrowser):
 
-    sklearn_datasets = ["boston", "breast_cancer", "diabetes", "iris", "wine", "digits"]
+    sklearn_datasets = ["breast_cancer", "diabetes", "iris", "wine", "digits"]
 
     def __init__(self):
         super(DatasetBrowser, self).__init__()
