@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import absolute_import, print_function
@@ -168,19 +168,17 @@ class ADSDatasetWithTarget(ADSDataset):
             The top 'k' features to select.
         score_func: function
             Scoring function to use to rank the features. This scoring function should take a 2d array X(features)
-             and an array like y(target) and return a numeric score for each feature in the same order as X.
+            and an array like y(target) and return a numeric score for each feature in the same order as X.
 
-        See also
-
-        https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.f_regression.html
-
-        https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.f_classif.html
+        Notes
+        -----
+        See also https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.f_regression.html
+        and https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.f_classif.html
 
         Examples
         --------
-        ds = DatasetBrowser("sklearn").open("iris")
-
-        ds_small = ds.select_best_features(k=2)
+        >>> ds = DatasetBrowser("sklearn").open("iris")
+        >>> ds_small = ds.select_best_features(k=2)
         """
         tf = self._get_best_features_transformer(score_func=score_func, k=k)
         return self._build_new_dataset(
@@ -197,27 +195,30 @@ class ADSDatasetWithTarget(ADSDataset):
         """
         Return transformed dataset with several optimizations applied automatically.
         The optimizations include:
-           - Dropping constant and primary key columns, which has no predictive quality
-           - Imputation, to fill in missing values in noisy data.
-                - For continuous variables, fill with mean if less than 40% is missing, else drop.
-                - For categorical variables, fill with most frequent if less than 40% is missing, else drop.
-           - Dropping strongly co-correlated columns that tend to produce less generalizable models.
+
+        - Dropping constant and primary key columns, which has no predictive quality,
+        - Imputation, to fill in missing values in noisy data:
+
+            - For continuous variables, fill with mean if less than 40% is missing, else drop,
+            - For categorical variables, fill with most frequent if less than 40% is missing, else drop,
+
+        - Dropping strongly co-correlated columns that tend to produce less generalizable models.
+
         Parameters
         ----------
-        correlation_threshold: float, defaults to 0.7. It must be between 0 and 1, inclusive.
+        correlation_threshold: float, defaults to 0.7. It must be between 0 and 1, inclusive
             the correlation threshold where columns with correlation higher than the threshold will
-            be considered as strongly co-correated and recommended to be taken care of.
-
-        frac: Is superseded by sample_size.
-
-        sample_size: float, defaults to 1.0. Float, Range -> (0, 1].
+            be considered as strongly co-correlated and recommended to be taken care of.
+        frac: Is superseded by sample_size
+        sample_size: float, defaults to 1.0. Float, Range -> (0, 1]
             What fraction of the data should be used in the calculation?
+        correlation_methods: Union[list, str], defaults to 'pearson'
+
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
 
-        correlation_methods: Union[list, str], defaults to 'pearson'.
-            'pearson': Use Pearson's Correlation between continuous features.
-            'cramers v': Use Cramer's V correlations between categorical features.
-            'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features.
-            'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
             Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
 
         Returns
@@ -226,7 +227,7 @@ class ADSDatasetWithTarget(ADSDataset):
 
         Examples
         --------
-        ds_clean = ds.auto_transform()
+        >>> ds_clean = ds.auto_transform()
         """
         frac = deprecate_default_value(
             frac,
@@ -317,39 +318,41 @@ class ADSDatasetWithTarget(ADSDataset):
     ):
         """
         Returns a pandas dataframe with suggestions for dataset optimization. This includes:
-            - Identifying constant and primary key columns, which has no predictive quality.
-            - Imputation, to fill in missing values in noisy data.
-                - For continuous variables, fill with mean if less than 40% is missing, else drop.
-                - For categorical variables, fill with most frequent if less than 40% is missing, else drop.
-            - Identifying strongly co-correlated columns that tend to produce less generalizable models.
-            - Automatically balancing dataset for classification problems using up or down sampling.
+
+        - Identifying constant and primary key columns, which has no predictive quality,
+        - Imputation, to fill in missing values in noisy data:
+
+            - For continuous variables, fill with mean if less than 40% is missing, else drop,
+            - For categorical variables, fill with most frequent if less than 40% is missing, else drop,
+
+        - Identifying strongly co-correlated columns that tend to produce less generalizable models,
+        - Automatically balancing dataset for classification problems using up or down sampling.
+
         Parameters
         ----------
-        correlation_methods: Union[list, str], default to 'pearson'.
-            'pearson': Use Pearson's Correlation between continuous features.
-            'cramers v': Use Cramer's V correlations between categorical features
-            'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features
-            'all' is equivalent to ['pearson', 'cramers v', 'correlation ratio']
+        correlation_methods: Union[list, str], default to 'pearson'
+
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+
             Or a list containing any combination of these methods, for example, ['pearson', 'cramers v']
-
-        print_code: bool. Defaults to True.
+        print_code: bool, Defaults to True
             Print Python code for the suggested actions.
-
-        correlation_threshold: float. Defaults to 0.7. It must be between 0 and 1, inclusive.
+        correlation_threshold: float. Defaults to 0.7. It must be between 0 and 1, inclusive
             the correlation threshold where columns with correlation higher than the threshold will
             be considered as strongly co-correated and recommended to be taken care of.
-
-        frac: Is superseded by sample_size.
-
-        sample_size: float, defaults to 1.0. Float, Range -> (0, 1].
+        frac: Is superseded by sample_size
+        sample_size: float, defaults to 1.0. Float, Range -> (0, 1]
             What fraction of the data should be used in the calculation?
+        overwrite:
+            Is deprecated and replaced by force_recompute.
+        force_recompute: bool, default to be False
 
-        overwrite: Is deprecated and replaced by force_recompute.
-
-        force_recompute: bool, default to be False.
-            If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
-            it returns the cached correlation matrix.
-            If True, it calculates the correlation matrix regardless whether there is cached result or not.
+            - If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
+              it returns the cached correlation matrix.
+            - If True, it calculates the correlation matrix regardless whether there is cached result or not.
 
         Returns
         -------
@@ -357,7 +360,7 @@ class ADSDatasetWithTarget(ADSDataset):
 
         Examples
         --------
-        suggestion_df = ds.suggest_recommendations(correlation_threshold=0.7)
+        >>> suggestion_df = ds.suggest_recommendations(correlation_threshold=0.7)
         """
         frac = deprecate_default_value(
             frac,
@@ -486,38 +489,42 @@ class ADSDatasetWithTarget(ADSDataset):
     ):
         """
         Generate recommendations for dataset optimization. This includes:
-            - Identifying constant and primary key columns, which has no predictive quality.
-            - Imputation, to fill in missing values in noisy data.
-                - For continuous variables, fill with mean if less than 40% is missing, else drop.
-                - For categorical variables, fill with most frequent if less than 40% is missing, else drop.
-            - Identifying strongly co-correlated columns that tend to produce less generalizable models.
-            - Automatically balancing dataset for classification problems using up or down sampling.
+
+        - Identifying constant and primary key columns, which has no predictive quality,
+        - Imputation, to fill in missing values in noisy data:
+
+            - For continuous variables, fill with mean if less than 40% is missing, else drop,
+            - For categorical variables, fill with most frequent if less than 40% is missing, else drop,
+
+        - Identifying strongly co-correlated columns that tend to produce less generalizable models,
+        - Automatically balancing dataset for classification problems using up or down sampling.
+
         Parameters
         ----------
-        correlation_methods: Union[list, str], default to 'pearson'.
-            'pearson': Use Pearson's Correlation between continuous features.
-            'cramers v': Use Cramer's V correlations between categorical features.
-            'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features.
-            'all' is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
-            Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
+        correlation_methods: Union[list, str], default to 'pearson'
 
-        correlation_threshold: float, defaults to 0.7. It must be between 0 and 1, inclusive.
+            - 'pearson': Use Pearson's Correlation between continuous features,
+            - 'cramers v': Use Cramer's V correlations between categorical features,
+            - 'correlation ratio': Use Correlation Ratio Correlation between categorical and continuous features,
+            - 'all': Is equivalent to ['pearson', 'cramers v', 'correlation ratio'].
+
+            Or a list containing any combination of these methods, for example, ['pearson', 'cramers v'].
+        correlation_threshold: float, defaults to 0.7. It must be between 0 and 1, inclusive
             The correlation threshold where columns with correlation higher than the threshold will
             be considered as strongly co-correlated and recommended to be taken care of.
-
-        frac: Is superseded by sample_size.
-
-        sample_size: float, defaults to 1.0. Float, Range -> (0, 1].
+        frac: Is superseded by sample_size
+        sample_size: float, defaults to 1.0. Float, Range -> (0, 1]
             What fraction of the data should be used in the calculation?
+        overwrite:
+            Is deprecated and replaced by force_recompute.
+        force_recompute: bool, default to be False
 
-        overwrite: Is deprecated and replaced by force_recompute.
+            - If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
+              it returns the cached correlation matrix.
+            - If True, it calculates the correlation matrix regardless whether there is cached result or not.
 
-        force_recompute: bool, default to be False.
-            If False, it calculates the correlation matrix if there is no cached correlation matrix. Otherwise,
-            it returns the cached correlation matrix.
-            If True, it calculates the correlation matrix regardless whether there is cached result or not.
-
-        display_format: string, defaults to 'widget'. Should be either 'widget' or 'table'. If 'widget',
+        display_format: string, defaults to 'widget'.
+            Should be either 'widget' or 'table'. If 'widget',
             a GUI style interface is popped out; if 'table', a table of suggestions is shown.
         """
         frac = deprecate_default_value(
@@ -604,9 +611,8 @@ class ADSDatasetWithTarget(ADSDataset):
 
         Examples
         --------
-        ds = ds.set_target('target_class')
-
-        assert(ds.type_of_target() == 'categorical')
+        >>> ds = ds.set_target('target_class')
+        >>> assert(ds.type_of_target() == 'categorical')
         """
         return self.target.type
 
@@ -618,9 +624,10 @@ class ADSDatasetWithTarget(ADSDataset):
         ----------
         test_size: Union[float, int], optional, default=0.1
         random_state: Union[int, RandomState], optional, default=None
-                If int, random_state is the seed used by the random number generator;
-                If RandomState instance, random_state is the random number generator;
-                If None, the random number generator is the RandomState instance used by np.random.
+
+                - If int, random_state is the seed used by the random number generator;
+                - If RandomState instance, random_state is the random number generator;
+                - If None, the random number generator is the RandomState instance used by np.random.
 
         Returns
         -------
@@ -629,9 +636,8 @@ class ADSDatasetWithTarget(ADSDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        train, test = ds.train_test_split()
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> train, test = ds.train_test_split()
         """
         X_train, X_test, y_train, y_test = train_test_split(
             self.df.drop(self.target.name, axis=1),
@@ -660,9 +666,10 @@ class ADSDatasetWithTarget(ADSDataset):
         test_size: Union[float, int], optional, default=0.1
         validation_size: Union[float, int], optional, default=0.1
         random_state: Union[int, RandomState], optional, default=None
-                If int, random_state is the seed used by the random number generator;
-                If RandomState instance, random_state is the random number generator;
-                If None, the random number generator is the RandomState instance used by np.random.
+
+                - If int, random_state is the seed used by the random number generator;
+                - If RandomState instance, random_state is the random number generator;
+                - If None, the random number generator is the RandomState instance used by np.random.
 
         Returns
         -------
@@ -671,9 +678,8 @@ class ADSDatasetWithTarget(ADSDataset):
 
         Examples
         --------
-        ds = DatasetFactory.open("data.csv")
-
-        train, valid, test = ds.train_validation_test_split()
+        >>> ds = DatasetFactory.open("data.csv")
+        >>> train, valid, test = ds.train_validation_test_split()
         """
         train, test = self.train_test_split(
             test_size=test_size, random_state=random_state
