@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import
@@ -49,6 +49,7 @@ from ads.type_discovery.typed_feature import (
 from ads.type_discovery.typed_feature import TypedFeature
 from typing import Callable, Tuple
 from ocifs import OCIFileSystem
+from ads.common.runtime_dependency import runtime_dependency
 
 default_snapshots_dir = None
 default_storage_options = None
@@ -93,7 +94,7 @@ class DatasetFactory:
             By default, the format would be inferred from the ending of the dataset file path.
         reader_fn: Callable, default: None
             The user may pass in their own custom reader function.
-            It must accept (path, **kwarg) and return a pandas DataFrame
+            It must accept `(path, **kwarg)` and return a pandas DataFrame
         name: str, optional default: ""
         description: str, optional default: ""
             Text describing the dataset
@@ -136,23 +137,30 @@ class DatasetFactory:
 
         Examples
         --------
-        >>> ds = DatasetFactory.open("/path/to/data.data", format='csv', delimiter=" ", na_values="n/a", \
-                    skipinitialspace=True)
+        >>> ds = DatasetFactory.open("/path/to/data.data", format='csv', delimiter=" ",
+        ...          na_values="n/a", skipinitialspace=True)
 
-        >>> ds = DatasetFactory.open("/path/to/data.csv", target="col_1", prefix="col_",  skiprows=1, \
-                    encoding="ISO-8859-1")
+        >>> ds = DatasetFactory.open("/path/to/data.csv", target="col_1", prefix="col_",
+        ...           skiprows=1, encoding="ISO-8859-1")
 
-        >>> ds = DatasetFactory.open("oci://bucket@namespace/path/to/data.tsv", column_names=["col1", "col2", "col3"], header=0)
+        >>> ds = DatasetFactory.open("oci://bucket@namespace/path/to/data.tsv",
+        ...         column_names=["col1", "col2", "col3"], header=0)
 
-        >>> ds = DatasetFactory.open("oci://bucket@namespace/path/to/data.csv", storage_options={"config": "~/.oci/config",
-                    "profile": "USER_2"}, delimiter = ';')
+        >>> ds = DatasetFactory.open("oci://bucket@namespace/path/to/data.csv",
+        ...         storage_options={"config": "~/.oci/config",
+        ...         "profile": "USER_2"}, delimiter = ';')
 
-        >>> ds = DatasetFactory.open("/path/to/data.parquet", engine='pyarrow', types={"col1": "ordinal", \
-                    "col2": "categorical", "col3" : "continuous", "col4" : "float64"})
+        >>> ds = DatasetFactory.open("/path/to/data.parquet", engine='pyarrow',
+        ...         types={"col1": "ordinal",
+        ...                "col2": "categorical",
+        ...                "col3" : "continuous",
+        ...                "col4" : "float64"})
 
-        >>> ds = DatasetFactory.open(df, target="class", sample_max_rows=5000, positive_class="yes")
+        >>> ds = DatasetFactory.open(df, target="class", sample_max_rows=5000,
+        ...          positive_class="yes")
 
-        >>> ds = DatasetFactory.open("s3://path/to/data.json.gz", format="json", compression="gzip", orient="records")
+        >>> ds = DatasetFactory.open("s3://path/to/data.json.gz", format="json",
+        ...         compression="gzip", orient="records")
         """
         if npartitions:
             warnings.warn(
@@ -234,20 +242,25 @@ class DatasetFactory:
         -------
         dataset: an object of ADSDataset target is not specified, otherwise an object of ADSDatasetWithTarget tagged
                   according to the type of target
+
         Examples
         --------
-        df = pd.DataFrame(data)
-
-        ds = from_dataframe(df)
+        >>> df = pd.DataFrame(data)
+        >>> ds = from_dataframe(df)
         """
         return DatasetFactory.open(df, target=target, **kwargs)
 
     @staticmethod
+    @runtime_dependency(
+        module="ipywidgets",
+        object="HTML",
+        is_for_notebook_only=True,
+        install_from="oracle-ads[notebook]",
+    )
     def list_snapshots(snapshot_dir=None, name="", storage_options=None, **kwargs):
         """
         Displays the URIs for dataset snapshots under the given directory path.
 
-
         Parameters
         ----------
         snapshot_dir: str
@@ -255,15 +268,17 @@ class DatasetFactory:
             The path can contain protocols such as oci, s3.
         name: str, optional
             The list of snapshots in the directory gets filtered by the name. Accepts glob expressions.
-            default = "ads_"
+            default = `"ads_"`
         storage_options: dict
             Parameters passed on to the backend filesystem class.
 
         Example
         --------
-        DatasetFactory.list_snapshots(snapshot_dir="oci://my_bucket/snapshots_dir", name="ads_iris_")
-        returns a list of all snapshots (recursively) saved to obj storage bucket "my_bucket" with prefix
-                "/snapshots_dir/ads_iris_**" sorted by time created.
+        >>> DatasetFactory.list_snapshots(snapshot_dir="oci://my_bucket/snapshots_dir",
+        ...             name="ads_iris_")
+
+        Returns a list of all snapshots (recursively) saved to obj storage bucket `"my_bucket"` with prefix
+        `"/snapshots_dir/ads_iris_**"` sorted by time created.
         """
         if snapshot_dir is None:
             snapshot_dir = default_snapshots_dir
@@ -323,13 +338,6 @@ class DatasetFactory:
 
         # display in HTML format if sdk is run in notebook mode
         if utils.is_notebook():
-
-            try:
-                from ipywidgets import HTML
-            except ModuleNotFoundError as e:
-                utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
-                raise e
-
             display(
                 HTML(
                     list_df.style.set_table_attributes("class=table")
@@ -342,7 +350,7 @@ class DatasetFactory:
     @staticmethod
     def download(remote_path, local_path, storage=None, overwrite=False):
         """
-        Download a remote file or directory to local storage
+        Download a remote file or directory to local storage.
 
         Parameters
         ---------
@@ -357,7 +365,8 @@ class DatasetFactory:
 
         Examples
         ---------
-        DatasetFactory.download("oci://Bucket/prefix/to/data/*.csv", "/home/datascience/data/")
+        >>> DatasetFactory.download("oci://Bucket/prefix/to/data/*.csv",
+        ...         "/home/datascience/data/")
         """
         if storage is None:
             if default_storage_options is not None:
@@ -444,7 +453,7 @@ class DatasetFactory:
     @staticmethod
     def set_default_storage(snapshots_dir=None, storage_options=None):
         """
-        Set default storage directory and options
+        Set default storage directory and options.
 
         Both snapshots_dir and storage_options can be overridden at the API scope.
 
@@ -699,14 +708,10 @@ class CustomFormatReaders:
         return get_data(path)
 
     @staticmethod
+    @runtime_dependency(
+        module="pandavro", object="read_avro", install_from="oracle-ads[data]"
+    )
     def read_avro(path: str, **kwargs) -> pd.DataFrame:
-
-        try:
-            from pandavro import read_avro
-        except ModuleNotFoundError as e:
-            utils._log_missing_module("pandavro", "oracle-ads[data]")
-            raise e
-
         return read_avro(path, **kwargs)
 
     DEFAULT_SQL_CHUNKSIZE = 12007
@@ -840,13 +845,15 @@ class CustomFormatReaders:
     @staticmethod
     def read_xml(path: str, **kwargs) -> pd.DataFrame:
         """
-        Load data from xml file
+        Load data from xml file.
+
         Parameters
         ----------
         path: str
             Path to XML file
         storage_options: dict, optional
             Storage options passed to Pandas to read the file.
+
         Returns
         -------
         dataframe : pandas.DataFrame
