@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import
@@ -55,9 +55,11 @@ class Plotting:
         choices = self._get_plot_method()  # add (plot_type='{0}') in plot method"
         if len(choices) > 1:
             logger.info(f"Recommended plot type is {choices[0][1].__name__}.")
+
             logger.info(
-                "Available plot types are "
-                + ", ".join([x[1].name for x in choices] + ".")
+                "Available plot types are ",
+                ", ".join([x[1].__name__ for x in choices]),
+                ".",
             )
         self.show_in_notebook()
         return ""
