@@ -1,16 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import copy
 import importlib
 
 from IPython.core.display import display
-from ipywidgets import HBox, Label, Layout, VBox, widgets, HTML, ButtonStyle
-
-from ads.common import utils
+from ads.common.runtime_dependency import runtime_dependency
 from ads.dataset import logger
 
 
@@ -32,6 +30,9 @@ class Recommendation:
         "Fix imbalance in dataset",
     ]
 
+    @runtime_dependency(
+        module="ipywidgets.widgets", install_from="oracle-ads[notebook]"
+    )
     def __init__(self, ds, recommendation_transformer):
         self.recommendation_transformer = recommendation_transformer
         self.reco_dict = recommendation_transformer.reco_dict_
@@ -139,6 +140,7 @@ class Recommendation:
         if len(self.reco_dict) == 0:
             logger.info("No recommendations.")
             return
+
         self._display()
 
     def _display(self):
