@@ -1,29 +1,18 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
-import collections
-from collections import Counter
-
 import geopandas
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import seaborn as sns
 import itertools
 
-from sklearn.decomposition import PCA
-
 import six
-from IPython.core.display import display
-from dask.array import stats
-from ipywidgets import widgets, HTML, HBox, VBox, Box, Layout, Label
 from matplotlib.patches import BoxStyle
-from wordcloud import WordCloud, STOPWORDS
-from distributed.client import CancelledError
 
 from ads.dataset.label_encoder import DataFrameLabelEncoder
 from sklearn.feature_selection import SelectKBest
@@ -31,14 +20,12 @@ from sklearn.feature_selection import chi2
 from sklearn.preprocessing import MinMaxScaler
 
 import matplotlib.font_manager
-import ads.environment.ml_runtime as runtime
 from ads.common import utils, logger
 from ads.dataset.helper import (
     fix_column_names,
     convert_columns,
     get_feature_type,
     convert_to_html,
-    DatasetDefaults,
 )
 from ads.dataset.plot import Plotting
 from ads.dataset.progress import DummyProgressBar
@@ -61,7 +48,7 @@ from ads.type_discovery.typed_feature import (
 
 class PandasDataset(object):
     """
-    This class provides APIs that can work on a sampled dataset
+    This class provides APIs that can work on a sampled dataset.
     """
 
     def __init__(
@@ -72,7 +59,7 @@ class PandasDataset(object):
         metadata=None,
         progress=DummyProgressBar(),
     ):
-        self.client = runtime.compute_accelerator()
+        self.client = None
         self.sampled_df = fix_column_names(sampled_df)
         self.correlation = None
         self.feature_dist_html_dict = {}
@@ -104,7 +91,7 @@ class PandasDataset(object):
                     }
                 except Exception as e:
                     print(
-                        f"An error occured while performing typed discovery on this dataset. Please try running again with "
+                        f"An error occured while performing typed discovery on this dataset. Try running again with "
                         f"`type_discovery=False`"
                     )
                     raise e
@@ -171,44 +158,36 @@ class PandasDataset(object):
             #
             # count missing values
             #
-            d = {column_name: np.nan for column_name in self.ddf.columns}  # default
-            for column_name in self.ddf.columns:
+            d = {column_name: np.nan for column_name in self.df.columns}  # default
+            for column_name in self.df.columns:
                 self._update_multiple_outputs(
                     out, f"calculating missing values (<code>{column_name}</code>)..."
                 )
-                d[column_name] = self.ddf[column_name].isna().sum().compute()
+                d[column_name] = self.df[column_name].isna().sum()
 
             df_missing = pd.DataFrame.from_dict(d, orient="index", columns=["missing"])
 
             #
             # calculate skew
             #
-            d = {column_name: np.nan for column_name in self.ddf.columns}  # default
+            d = {column_name: np.nan for column_name in self.df.columns}  # default
             for column_name in self.numeric_columns:
                 self._update_multiple_outputs(
                     out, f"calculating skew (<code>{column_name}</code>)..."
                 )
-                if len(self.ddf[column_name].dropna()) > 0:
-                    d[column_name] = (
-                        stats.skew(self.ddf[column_name].dropna()).compute().item(0)
-                    )
+                if len(self.df[column_name].dropna()) > 0:
+                    d[column_name] = self.df[column_name].dropna().skew().item(0)
                 else:
                     d[column_name] = np.nan
             df_skew = pd.DataFrame.from_dict(d, orient="index", columns=["skew"])
             self._update_multiple_outputs(out, "calculating dataset statistics...")
-            for col in self.ddf.columns:
-                if df_missing["missing"][col] == len(self.ddf[col]):
-                    self.ddf[col] = self.ddf[col].astype(
-                        "object"
-                    )  # an column of null with type object is ignored by dask (while with type float will lead to error)
+            for col in self.df.columns:
+                if df_missing["missing"][col] == len(self.df[col]):
+                    self.df[col] = self.df[col].astype("object")
 
         #
         # compute descriptive dataset statistics
-        #
-        # there is a bug in dask where it cannot handle data with missing value.
-        # switch to use pandas for now
-        # self.ddf.describe(include='all').compute().round(2)
-        df_stats = self.ddf.compute().describe(include="all").round(2)
+        df_stats = self.df.describe(include="all").round(2)
 
         self._update_multiple_outputs(out, "transpose dataset statistics...")
         df_stats = df_stats.transpose()
@@ -339,7 +318,7 @@ class PandasDataset(object):
                     out.value = (
                         f"Analyzing cadinalities (<code>{column_name}</code>)..."
                     )
-                    unique = self.ddf[column_name].unique().compute().shape[0]
+                    unique = self.df[column_name].unique().shape[0]
                     if unique == n_rows:
                         accum.append(
                             {
@@ -367,7 +346,7 @@ class PandasDataset(object):
                     ):
                         out.value = f"Analyzing zeros (<code>{column_name}</code>)..."
                         # we've filtered on only columns that have a min value of 0 for speed
-                        zeros = self.ddf[self.ddf[column_name] == 0].compute().shape[0]
+                        zeros = self.df[self.df[column_name] == 0].shape[0]
                         zeros_pct = 100 * zeros / n_rows
                         if zeros_pct >= 10:
                             accum.append(
@@ -417,22 +396,22 @@ class PandasDataset(object):
             return html
 
         else:
-            return '<h3>No Feature warnings found</h3>'
-
+            return "<h3>No Feature warnings found</h3>"
 
     def summary(self, feature_name=None):
         """
         Display list of features & their datatypes.
-        Shows the column name and the feature's meta_data if given a specific feature name
+        Shows the column name and the feature's meta_data if given a specific feature name.
 
-        Parameters:
+        Parameters
         ----------
         date_col: str
-        The name of the feature
+            The name of the feature
 
         Returns
         -------
-        dict: a dictionary that contains requested information
+        dict
+            a dictionary that contains requested information
         """
 
         feature_n_datatype = {}
@@ -492,16 +471,17 @@ class PandasDataset(object):
 
     def timeseries(self, date_col):
         """
-        Supports any plotting operations where x=datetime
+        Supports any plotting operations where x=datetime.
 
-        Parameters:
+        Parameters
         ----------
         date_col: str
             The name of the feature to plot
 
         Returns
         -------
-        func: a plotting object that contains a date column and dataframe
+        func
+            a plotting object that contains a date column and dataframe
         """
 
         if date_col in self.feature_types and isinstance(
@@ -515,26 +495,28 @@ class PandasDataset(object):
         self, x, y=None, plot_type="infer", yscale=None, verbose=True, sample_size=0
     ):
         """
-        Supports plotting feature distribution, and relationship between features
+        Supports plotting feature distribution, and relationship between features.
 
-        Parameters:
+        Parameters
         ----------
         x: str
             The name of the feature to plot
         y: str, optional
             Name of the feature to plot against x
         plot_type: str, default: infer
-            Override the inferred plot type for certain combinations of the data types of x and y
-            By default, the best plot type is inferred based on x and y data types
+            Override the inferred plot type for certain combinations of the data types of x and y.
+            By default, the best plot type is inferred based on x and y data types.
             Valid values:
-            box_plot: discrete feature vs continuous feature
-                Draw a box plot to show distributions with respect to categories
-            scatter: continuous feature vs continuous feature
-                Draw a scatter plot with possibility of several semantic groupings
+
+            - box_plot - discrete feature vs continuous feature. Draw a box plot to show
+              distributions with respect to categories,
+            - scatter - continuous feature vs continuous feature. Draw a scatter plot
+              with possibility of several semantic groupings.
+
         yscale : str, optional
-            One of {"linear", "log", "symlog", "logit"}
+            One of {"linear", "log", "symlog", "logit"}.
             The y axis scale type to apply. Can be used when either x or y is an ordinal feature.
-        verbose: bool, default: True
+        verbose: bool, default True
             Displays Note/Tips if True
         """
         sample_size = int(sample_size)
@@ -549,7 +531,7 @@ class PandasDataset(object):
             sub_samp_df, self.feature_types, x, y=y, plot_type=plot_type, yscale=yscale
         )
         if verbose:
-            if len(self.ddf) != sub_samp_size:
+            if len(self.df) != sub_samp_size:
                 logger.info(f"Downsampling from dataset for graphing.")
         return plot
 
@@ -557,7 +539,7 @@ class PandasDataset(object):
         """
         Supports plotting Choropleth maps
 
-        Parameters:
+        Parameters
         ----------
         df: pandas dataframe
             The dataframe to plot
@@ -605,7 +587,6 @@ class PandasDataset(object):
     def _visualize_feature_distribution(self, html_widget):
         """
         This function is called once per dataset to generate html for feature distribution plots.
-        :return:
         """
         if len(self.feature_dist_html_dict) > 0:
             return self.feature_dist_html_dict
@@ -979,17 +960,26 @@ class PandasDataset(object):
                     stats = "\n".join(["  - word count: %d" % (len(word_freqs.keys()))])
                     text = text + "\n"
                     text += stats
-                    wordcloud = WordCloud(
-                        width=1000,
-                        height=int(1000 * (figsize[1] / figsize[0])),
-                        background_color="white",
-                        stopwords=set(STOPWORDS),
-                        max_words=50,
-                        max_font_size=75,
-                    ).fit_words(word_freqs)
+                    try:
+                        from wordcloud import WordCloud, STOPWORDS
+
+                        wordcloud = WordCloud(
+                            width=1000,
+                            height=int(1000 * (figsize[1] / figsize[0])),
+                            background_color="white",
+                            stopwords=set(STOPWORDS),
+                            max_words=50,
+                            max_font_size=75,
+                        ).fit_words(word_freqs)
+
+                        plt.imshow(wordcloud, interpolation="bilinear")
+                        plt.axis("off")
+                    except ModuleNotFoundError as e:
+                        utils._log_missing_module("wordcloud", "oracle-ads[text]")
+                        logger.info(
+                            "The text word cloud is not plotted due to missing dependency wordcloud."
+                        )
 
-                    plt.imshow(wordcloud, interpolation="bilinear")
-                    plt.axis("off")
             else:
                 ax.text(
                     -1.1,
