@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import, division
@@ -9,10 +9,11 @@ from __future__ import print_function, absolute_import, division
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import matplotlib.lines as mlines
-from matplotlib.ticker import FormatStrFormatter, StrMethodFormatter, NullFormatter
+from matplotlib.ticker import FormatStrFormatter
 import numpy as np
 import math
-from ads.common import utils, logger, model
+from ads.common import logger
+from ads.common.runtime_dependency import runtime_dependency
 import itertools
 from IPython.core.display import display
 import pandas as pd
@@ -172,30 +173,37 @@ class EvaluationPlot:
         """Gets the legend labels, resolves any conflicts such as length, and renders
         the labels for the plot
 
-        Args:
-            legend_labels (dict): key/value dictionary containing legend label data
+        Parameters
+        ----------
+        legend_labels (dict):
+            key/value dictionary containing legend label data
 
-        Returns:
-            Nothing
+        Returns
+        -------
+        Nothing
+
+        Examples
+        --------
+
+        EvaluationPlot.get_legend_labels({'class_0': 'green', 'class_1': 'yellow', 'class_2': 'red'})
         """
 
+        @runtime_dependency(
+            module="ipywidgets", object="HTML", install_from="oracle-ads[notebook]"
+        )
         def render_legend_labels(label_dict):
             encodings = pd.DataFrame(
                 pd.Series(label_dict, index=label_dict.keys()),
                 columns=["Shortened labels"],
             )
 
-            try:
-                from ipywidgets import HTML
-            except ModuleNotFoundError as e:
-                utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
-                raise e
-
             display(
                 HTML(
                     encodings.style.set_precision(4)
                     .set_properties(**{"text-align": "center"})
-                    .set_table_styles([dict(props=[("text-align", "center")])])
+                    .set_table_styles(
+                        [dict(selector="", props=[("text-align", "center")])]
+                    )
                     .set_table_attributes("class=table")
                     .set_caption(
                         '<div align="left"><b style="font-size:20px;">'
@@ -212,9 +220,10 @@ class EvaluationPlot:
             ):
                 render_legend_labels(legend_labels)
                 cls.legend_labels = legend_labels
-            logger.error(
-                "The provided `legend_labels` is neither a Python dict nor does not possess all possible class labels"
-            )
+            else:
+                logger.error(
+                    "The provided `legend_labels` is neither a Python dict nor does not possess all possible class labels."
+                )
             return
 
         # try to remove leading words
@@ -285,20 +294,24 @@ class EvaluationPlot:
     ):
         """Generates the evaluation plot
 
-        Args:
-            evaluation (DataFrame): DataFrame with models as columns and metrics as rows.
-            plots (str): The plot type based on class attribute `prob_type`.
-            num_classes (int):
-                The number of classes for the model.
-            perfect (bool, optional):
-                Whether to display the curve of a perfect classifier. Default value is `False`.
-            baseline (bool, optional):
-                Whether to display the curve of the baseline, featureless model. Default value is `True`.
-            legend_labels (dict, optional):
-                Legend labels dictionary. Default value is `None`.
+        Parameters
+        ----------
+        evaluation (DataFrame):
+            DataFrame with models as columns and metrics as rows.
+        plots (str):
+            The plot type based on class attribute `prob_type`.
+        num_classes (int):
+            The number of classes for the model.
+        perfect (bool, optional):
+            Whether to display the curve of a perfect classifier. Default value is `False`.
+        baseline (bool, optional):
+            Whether to display the curve of the baseline, featureless model. Default value is `True`.
+        legend_labels (dict, optional):
+            Legend labels dictionary. Default value is `None`. If legend_labels not specified class names will be used for plots.
 
-        Returns:
-            Nothing
+        Returns
+        -------
+        Nothing
         """
 
         cls.perfect = perfect
