@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import matplotlib.pyplot as plt
@@ -20,11 +20,11 @@ mpl.rcParams["axes.prop_cycle"] = cycler(
     color=["teal", "blueviolet", "forestgreen", "peru", "y", "dodgerblue", "r"]
 )
 
-from ads.common import utils
 from ads.evaluations.evaluation_plot import EvaluationPlot
 from ads.evaluations.statistical_metrics import ModelEvaluator
 from ads.dataset.dataset_with_target import ADSDatasetWithTarget
 from ads.common.model import ADSModel
+from ads.common.runtime_dependency import runtime_dependency
 
 
 class ADSEvaluator(object):
@@ -33,31 +33,41 @@ class ADSEvaluator(object):
 
     Attributes
     ----------
-    evaluations (list[DataFrame]): list of evaluations.
-    is_classifier (bool): Whether the model has a non-empty classes_ attribute indicating the presence of class labels.
-    legend_labels (list[str)]): List of legend labels.
-    metrics_to_show (list[str]): Names of metrics to show.
-    models (list[ads.common.model.ADSModel]): The object built using `ADSModel.from_estimator()`.
-    positive_class (str or int): The class to report metrics for binary dataset, assumed to be true.
-    show_full_name (bool): Whether to show the name of the evaluator in relevant contexts.
-    test_data (ads.common.data.ADSData): Test data to evaluate model on.
-    training_data (ads.common.data.ADSData): Training data to evaluate model.
+    evaluations : list[DataFrame]
+        list of evaluations.
+    is_classifier : bool
+        Whether the model has a non-empty `classes_` attribute indicating the presence of class labels.
+    legend_labels : dict
+        List of legend labels. Defaults to `None`.
+    metrics_to_show : list[str]
+        Names of metrics to show.
+    models : list[ads.common.model.ADSModel]
+        The object built using `ADSModel.from_estimator()`.
+    positive_class : str or int
+        The class to report metrics for binary dataset, assumed to be true.
+    show_full_name :bool
+        Whether to show the name of the evaluator in relevant contexts.
+    test_data : ads.common.data.ADSData
+        Test data to evaluate model on.
+    training_data : ads.common.data.ADSData
+        Training data to evaluate model.
 
-    Positive_Class_names (list): Class attribute listing the ways to represent positive classes
+    Positive_Class_names : list
+        Class attribute listing the ways to represent positive classes
 
     Methods
     -------
-    add_metrics(func, names):
+    add_metrics(func, names)
         Adds the listed metics to the evaluator it is called on
-    del_metrics(names):
+    del_metrics(names)
         Removes listed metrics from the evaluator object it is called on
-    add_models(models, show_full_name):
+    add_models(models, show_full_name)
         Adds the listed models to the evaluator object
-    del_models(names):
+    del_models(names)
         Removes the listed models from the evaluator object
-    show_in_notebook(plots, use_training_data, perfect, baseline, legend_labels):
+    show_in_notebook(plots, use_training_data, perfect, baseline, legend_labels)
         Visualize evalutation plots in the notebook
-    calculate_cost(tn_weight, fp_weight, fn_weight, tp_weight, use_training_data):
+    calculate_cost(tn_weight, fp_weight, fn_weight, tp_weight, use_training_data)
         Returns a cost associated with the input weights
     """
 
@@ -72,30 +82,41 @@ class ADSEvaluator(object):
         legend_labels=None,
         show_full_name=False,
     ):
-        """Creates an ads evaluator object
+        """Creates an ads evaluator object.
 
-        Args:
-            test_data (ads.common.data.ADSData instance): Test data to evaluate model on.
-                The object can be built using `ADSData.build()`.
-            models (list[ads.common.model.ADSModel]): The object can be built using
-                `ADSModel.from_estimator()`. Maximum length of the list is 3
-            training_data (ads.common.data.ADSData instance, optional): Training data to evaluate model
-                on and compare metrics against test data. The object can be built using `ADSData.build()`
-            positive_class (str or int, optional): The class to report metrics for binary dataset. If the
-                target classes is True or False, positive_class will be set to True by default. If the
-                dataset is multiclass or multilabel, this will be ignored.
-            legend_labels (list[str], optional): List of legend labels. Defaults to `None`.
-            show_full_name (bool, optional): Show the name of the evaluator object. Defaults to `False`.
+        Parameters
+        ----------
+        test_data : ads.common.data.ADSData instance
+            Test data to evaluate model on.
+            The object can be built using `ADSData.build()`.
+        models : list[ads.common.model.ADSModel]
+            The object can be built using `ADSModel.from_estimator()`.
+            Maximum length of the list is 3
+        training_data : ads.common.data.ADSData instance, optional
+            Training data to evaluate model on and compare metrics against test data.
+            The object can be built using `ADSData.build()`
+        positive_class : str or int, optional
+            The class to report metrics for binary dataset. If the target classes is True or False,
+            positive_class will be set to True by default. If the dataset is multiclass or multilabel,
+            this will be ignored.
+        legend_labels : dict, optional
+            List of legend labels. Defaults to `None`.
+            If legend_labels not specified class names will be used for plots.
+        show_full_name : bool, optional
+            Show the name of the evaluator object. Defaults to `False`.
 
-        Example::
+        Examples
+        --------
 
-            train, test = ds.train_test_split()
+        >>> train, test = ds.train_test_split()
+        >>> model1 = MyModelClass1.train(train)
+        >>> model2 = MyModelClass2.train(train)
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
 
-            model1 = MyModelClass1.train(train)
+        >>> legend_labels={'class_0': 'one', 'class_1': 'two', 'class_2': 'three'}
+        >>> multi_evaluator = ADSEvaluator(test, models=[model1, model2],
+        ...             legend_labels=legend_labels)
 
-            model2 = MyModelClass2.train(train)
-
-            evaluator = ADSEvaluator(test, [model1, model2])
         """
 
         self.evaluations = []
@@ -163,28 +184,27 @@ class ADSEvaluator(object):
         self.add_models(models, show_full_name=show_full_name)
 
     def add_metrics(self, funcs, names):
-        """Adds the listed metrics to the evaluator object it is called on
+        """Adds the listed metrics to the evaluator object it is called on.
 
-        Args:
-            funcs (list): The list of metrics to be added. This function will be provided `y_true`
-                and `y_pred`, the true and predicted values for each model.
-            names (list[str]): The list of metric names corresponding to the functions.
-
-        Returns:
-            Nothing
-
-        Example::
-
-            def f1(y_true, y_pred):
-                return np.max(y_true - y_pred)
-
-            evaluator = ADSEvaluator(test, [model1, model2])
-
-            evaluator.add_metrics([f1], ['Max Residual'])
-
-            evaluator.metrics
+        Parameters
+        ----------
+        funcs : list
+            The list of metrics to be added. This function will be provided `y_true`
+            and `y_pred`, the true and predicted values for each model.
+        names : list[str])
+            The list of metric names corresponding to the functions.
 
+        Returns
+        -------
+        Nothing
 
+        Examples
+        --------
+        >>> def f1(y_true, y_pred):
+        ...    return np.max(y_true - y_pred)
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> evaluator.add_metrics([f1], ['Max Residual'])
+        >>> evaluator.metrics
         Output table will include the desired metric
         """
 
@@ -219,26 +239,24 @@ class ADSEvaluator(object):
         setattr(self, "test_evaluations", self.evaluations[1])
 
     def del_metrics(self, names):
-        """Removes the listed metrics from the evaluator object it is called on
+        """Removes the listed metrics from the evaluator object it is called on.
 
         Parameters
         ----------
-        names: (list[str])
+        names : list[str]
             The list of names of metrics to be deleted. Names can be found by calling
             `evaluator.test_evaluations.index`.
 
-        Return
-            None
-                `None`
-
-        Example::
-
-            evaluator = ADSEvaluator(test, [model1, model2])
-
-            evaluator.del_metrics(['mse])
-
-            evaluator.metrics
+        Returns
+        -------
+        None
+            `None`
 
+        Examples
+        --------
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> evaluator.del_metrics(['mse])
+        >>> evaluator.metrics
         Output table will exclude the desired metric
         """
         self.evaluations[1].drop(index=names, inplace=True)
@@ -247,21 +265,24 @@ class ADSEvaluator(object):
         self.metrics_to_show = [met for met in self.metrics_to_show if met not in names]
 
     def add_models(self, models, show_full_name=False):
-        """Adds the listed models to the evaluator object it is called on
+        """Adds the listed models to the evaluator object it is called on.
 
-        Args:
-            models (list[ADSModel]): The list of models to be added
-            show_full_name (bool, optional). Whether to show the full model name. Defaults to False
-                ** NOT USED **
+        Parameters
+        ----------
+        models : list[ADSModel]
+            The list of models to be added
+        show_full_name : bool, optional
+            Whether to show the full model name. Defaults to False.
+            ** NOT USED **
 
-        Returns:
-            Nothing
+        Returns
+        -------
+        Nothing
 
-        Example::
-
-            evaluator = ADSEvaluator(test, [model1, model2])
-
-            evaluator.add_models("model3])
+        Examples
+        --------
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> evaluator.add_models("model3])
         """
 
         if type(models) is list:
@@ -305,23 +326,24 @@ class ADSEvaluator(object):
             setattr(self, "test_evaluations", self.evaluations[1])
 
     def del_models(self, names):
-        """Removes the listed models from the evaluator object it is called on
+        """Removes the listed models from the evaluator object it is called on.
 
-        Args:
-            names (list[str]): the list of models to be delete. Names are the model names by default, and
-                assigned internally when conflicts exist. Actual names can be found using
-                `evaluator.test_evaluations.columns`
+        Parameters
+        ----------
+        names : list[str]
+            the list of models to be delete. Names are the model names by default, and
+            assigned internally when conflicts exist. Actual names can be found using
+            `evaluator.test_evaluations.columns`
 
-        Returns:
-            Nothing
+        Returns
+        -------
+        Nothing
 
-        Example::
-
-            model3.rename("model3")
-
-            evaluator = ADSEvaluator(test, [model1, model2, model3])
-
-            evaluator.del_models([model3])
+        Examples
+        --------
+        >>> model3.rename("model3")
+        >>> evaluator = ADSEvaluator(test, [model1, model2, model3])
+        >>> evaluator.del_models([model3])
         """
 
         if type(names) is list:
@@ -338,30 +360,41 @@ class ADSEvaluator(object):
         baseline=True,
         legend_labels=None,
     ):
-        """Visualize evaluation plots
+        """Visualize evaluation plots.
 
         Parameters
         ----------
-            plots: (list, optional)
-                Filter the plots that are displayed. Defaults to None
-                The name of the plots are as below:
-                    * **regression**: residuals_qq, residuals_vs_fitted
-                    * **binary classification**: normalized_confusion_matrix, roc_curve, pr_curve
-                    * **multi class classification**: normalized_confusion_matrix, precision_by_label, recall_by_label, f1_by_label
-            use_training_data: (bool, optional)
-                Use training data to generate plots. Defaults to `False`.
-                By default, this method uses test data to generate plots
+        plots : list, optional
+            Filter the plots that are displayed. Defaults to None. The name of the plots are as below:
 
-        Return
-        ------
-            None
-                Nothing. Outputs several evaluation plots as specified by `plots`.
+                - regression - residuals_qq, residuals_vs_fitted
+                - binary classification - normalized_confusion_matrix, roc_curve, pr_curve
+                - multi class classification - normalized_confusion_matrix, precision_by_label, recall_by_label, f1_by_label
 
-        Examples::
+        use_training_data : bool, optional
+            Use training data to generate plots. Defaults to `False`.
+            By default, this method uses test data to generate plots
+        legend_labels : dict, optional
+            Rename legend labels, that used for multi class classification plots. Defaults to None.
+            legend_labels dict keys are the same as class names. legend_labels dict values are strings.
+            If legend_labels not specified class names will be used for plots.
 
-            evaluator = ADSEvaluator(test, [model1, model2])
+        Returns
+        -------
+        None
+            Nothing. Outputs several evaluation plots as specified by `plots`.
 
-            evaluator.show_in_notebook()
+        Examples
+        --------
+
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> evaluator.show_in_notebook()
+
+        >>> legend_labels={'class_0': 'green', 'class_1': 'yellow', 'class_2': 'red'}
+        >>> multi_evaluator = ADSEvaluator(test, [model1, model2],
+        ...             legend_labels=legend_labels)
+        >>> multi_evaluator.show_in_notebook(plots=["normalized_confusion_matrix",
+        ...             "precision_by_label", "recall_by_label", "f1_by_label"])
         """
 
         # get evaluations
@@ -384,31 +417,30 @@ class ADSEvaluator(object):
     def calculate_cost(
         self, tn_weight, fp_weight, fn_weight, tp_weight, use_training_data=False
     ):
-        """Returns a cost associated with the input weights
+        """Returns a cost associated with the input weights.
 
         Parameters
         ----------
-            tn_weight: (int, float)
-                The weight to assign true negatives in calculating the cost
-            fp_weight: (int, float)
-                The weight to assign false positives in calculating the cost
-            fn_weight: (int, float)
-                The weight to assign false negatives in calculating the cost
-            tp_weight: (int, float)
-                The weight to assign true positives in calculating the cost
-            use_training_data: (bool, optional)
-                Use training data to pull the metrics. Defaults to False
+        tn_weight : int, float
+            The weight to assign true negatives in calculating the cost
+        fp_weight : int, float
+            The weight to assign false positives in calculating the cost
+        fn_weight : int, float
+            The weight to assign false negatives in calculating the cost
+        tp_weight : int, float
+            The weight to assign true positives in calculating the cost
+        use_training_data : bool, optional
+            Use training data to pull the metrics. Defaults to False
 
-        Return
-        ------
-            :class:`pandas.DataFrame`
-                DataFrame with the cost calculated for each model
+        Returns
+        -------
+        :class:`pandas.DataFrame`
+            DataFrame with the cost calculated for each model
 
-        Example::
-
-            evaluator = ADSEvaluator(test, [model1, model2])
-
-            costs_table = evaluator.calculate_cost(0, 10, 1000, 0)
+        Examples
+        --------
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> costs_table = evaluator.calculate_cost(0, 10, 1000, 0)
         """
 
         if len(self.classes) != 2:
@@ -434,17 +466,17 @@ class ADSEvaluator(object):
         return cost_df
 
     class EvaluationMetrics(object):
-        """Class holding evaluation metrics
+        """Class holding evaluation metrics.
 
-        Atrributes
+        Attributes
         ----------
-        ev_test (list):
+        ev_test : list
             evaluation test metrics
-        ev_train (list):
+        ev_train : list
             evaluation training metrics
-        use_training (bool):
+        use_training : bool
             use training data
-        less_is_more (list):
+        less_is_more : list
             metrics list
 
         Methods
@@ -492,7 +524,7 @@ class ADSEvaluator(object):
         @precision.setter
         def precision(self, value):
             """
-            set precision to @property of the class
+            Set precision to @property of the class.
             """
             if not isinstance(value, int):
                 if not (isinstance(value, float) and value.is_integer()):
@@ -504,23 +536,30 @@ class ADSEvaluator(object):
 
         def show_in_notebook(self, labels=DEFAULT_LABELS_MAP):
             """
-            Visualizes evaluation metrics as a color coded table
+            Visualizes evaluation metrics as a color coded table.
 
-            Args:
-                lables (dictionary): map printing specific labels for metrics display
+            Parameters
+            ----------
+            labels : dictionary
+                map printing specific labels for metrics display
 
-            Returning:
-                Nothing
+            Returns
+            -------
+            Nothing
             """
 
             def highlight_max(s):
                 """Highlight the maximum in a Series yellow.
 
-                Args:
-                    s (series object): the series being evaluated
+                Parameters
+                ----------
+                s : series object
+                    the series being evaluated
 
-                Returns:
-                    (list): containing background color data or empty if not max
+                Returns
+                -------
+                list
+                    containing background color data or empty if not max
                 """
                 if s.name not in self.less_is_more:
                     is_max = s == s.max()
@@ -535,14 +574,18 @@ class ADSEvaluator(object):
 
             def _pretty_label(df, labels, copy=False):
                 """
-                Output specified labels in proper format
+                Output specified labels in proper format.
                 If the labels are provided in then used them. Otherwise, use default.
 
-                Args:
-                    lables (dictionary): map printing specific labels for metrics display
+                Parameters
+                ----------
+                labels : dictionary
+                    map printing specific labels for metrics display
 
-                Returns:
-                    (dataframe): dataframe with index names modified according to input labels
+                Returns
+                -------
+                dataframe
+                    dataframe with index names modified according to input labels
                 """
                 if copy:
                     df = df.copy()
@@ -550,26 +593,28 @@ class ADSEvaluator(object):
                     df.rename(index={k: v}, inplace=True)
                 return df
 
+            @runtime_dependency(
+                module="ipywidgets", object="HTML", install_from="oracle-ads[notebook]"
+            )
             def _display_metrics(df, data_name, labels, precision):
                 """
                 display metrics on web page
 
-                Args:
-                    df (dataframe): metrics in dataframe format
-                    data_name (string): name of data given metrics df describe
-                    lables (dictionary): map printing specific labels for metrics display
-                    precision (int): precision for metrics display
+                Parameters
+                ----------
+                df : dataframe
+                    metrics in dataframe format
+                data_name : string
+                    name of data given metrics df describe
+                labels : dictionary
+                    map printing specific labels for metrics display
+                precision : int
+                    precision for metrics display
 
-                Returns:
-                    Nothing
+                Returns
+                -------
+                Nothing
                 """
-
-                try:
-                    from ipywidgets import HTML
-                except ModuleNotFoundError as e:
-                    utils._log_missing_module("ipywidgets", "oracle-ads[notebook]")
-                    raise e
-
                 display(
                     HTML(
                         _pretty_label(df, labels)
@@ -597,21 +642,20 @@ class ADSEvaluator(object):
 
         Parameters
         ----------
-            metrics: (list, optional)
-                Request metrics to pull. Defaults to all.
-            use_training_data: (bool, optional)
-                Use training data to pull metrics. Defaults to False
+        metrics : list, optional
+            Request metrics to pull. Defaults to all.
+        use_training_data : bool, optional
+            Use training data to pull metrics. Defaults to False
 
-        Return
-        ------
-            dict
-                The requested raw metrics for each model. If `metrics` is `None` return all.
+        Returns
+        -------
+        dict
+            The requested raw metrics for each model. If `metrics` is `None` return all.
 
-        Example::
-
-            evaluator = ADSEvaluator(test, [model1, model2])
-
-            raw_metrics_dictionary = evaluator.raw_metrics()
+        Examples
+        --------
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> raw_metrics_dictionary = evaluator.raw_metrics()
         """
 
         [train_met, test_met] = self.evaluations
@@ -633,21 +677,15 @@ class ADSEvaluator(object):
     def metrics(self):
         """Returns evaluation metrics
 
-        Parameters
-        ----------
-        None
-
-        Return
-        ------
-            metrics
-                HTML representation of a table comparing relevant metrics.
-
-        Example::
-
-            evaluator = ADSEvaluator(test, [model1, model2])
-
-            evaluator.metrics
+        Returns
+        -------
+        metrics
+            HTML representation of a table comparing relevant metrics.
 
+        Examples
+        --------
+        >>> evaluator = ADSEvaluator(test, [model1, model2])
+        >>> evaluator.metrics
         Outputs table displaying metrics.
         """
 
