@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import numpy as np
@@ -59,59 +59,57 @@ class MLXGlobalExplainer(GlobalExplainer):
         explanation. If the dataset is text, approximates a global explanation by
         generating and aggregating multiple local explanations.
 
-
         Parameters
         ----------
-
         n_iter : int, optional
-
             Number of iterations of the permutation importance algorithm to
             perform. Increasing this value increases the quality/stability of
             the explanation, but increases the explanation time. Default value is 20.
-
         sampling : dict, optional
-
             If not `None`, the dataset is clustered or sampled according to the
             provided technique. `sampling` is a dictionary containing the technique
             to use and the corresponding parameters. Format is described below:
-                - **technique**: Either `cluster` or `random`.
-                - If **cluster**, also requires:
-                    - `eps`: Maximum distance between two samples to be considered
-                      in the same cluster.
-                    - `min_samples`: Minimum number of samples to include in each
-                      cluster.
-                - If **random**, also requires:
-                    - `n_samples`: Number of samples to return.
+
+            - `technique`: Either `cluster` or `random`.
+            - If `cluster`, also requires:
+
+                - `eps`: Maximum distance between two samples to be considered
+                  in the same cluster.
+                - `min_samples`: Minimum number of samples to include in each
+                  cluster.
+
+            - If `random`, also requires:
+
+                - `n_samples`: Number of samples to return.
 
             By default None. Note that text datasets are always sampled. If not provided
             with a sampling option, defaults to 40 random samples.
-
         balance : bool, optional
-
             If True, the dataset will be balanced via sampling. If 'sampling' is not
             set, the sampling technique defaults to 'random'.
-
         scoring_metric : string, optional
-
             If specified, propegates a string indicating the supported scoring metric.
             The scoring metrics available out of the box are the ones made available
-            by ScyPy.
+            by ScyPy. Supported Metrics:
 
-            Supported Metrics:
+            - Multi-class Classification
 
-                Multi-class Classification:
-                    `f1_weighted`, `f1_micro`, `f1_macro`, `recall_weighted`, `recall_micro`, `recall_macro`,
-                    `accuracy`, `balanced_accuracy`, `roc_auc`, `precision_weighted`, `precision_macro`,
-                    `precision_micro`
-                Binary Classification:
-                    Same as multi-class classification.
-                Regression
-                    r2, neg_mean_squared_error, neg_root_mean_squared_error, neg_mean_absolute_error,
-                    neg_median_absolute_error, neg_mean_absolute_percentage_error,
-                    neg_symmetric_mean_absolute_percentage_error
+                `f1_weighted`, `f1_micro`, `f1_macro`, `recall_weighted`, `recall_micro`, `recall_macro`,
+                `accuracy`, `balanced_accuracy`, `roc_auc`, `precision_weighted`, `precision_macro`,
+                `precision_micro`
 
-        Return
-        ------
+            - Binary Classification
+
+                Same as multi-class classification
+
+            - Regression
+
+                `r2`, `neg_mean_squared_error`, `neg_root_mean_squared_error`, `neg_mean_absolute_error`,
+                `neg_median_absolute_error`, `neg_mean_absolute_percentage_error`,
+                `neg_symmetric_mean_absolute_percentage_error`
+
+        Returns
+        -------
         :class:FeatureImportance
             `FeaturePermutationImportance` explanation object.
 
@@ -202,12 +200,10 @@ class MLXGlobalExplainer(GlobalExplainer):
 
         features : list of int, list of str
             List of feature names or feature indices to explain.
-
         partial_range : tuple, optional
             2-tuple with the minimum and maximum percentile values to consider for the PDP from
             the feature's train distribution. Must be between 0.0 and 1.0.
             Defaults to `partial_range = (0.05, 0.95)`.
-
         num_samples : int, optional
             Maximum number of samples to generate for each feature within the
             `partial_range` of its value distribution. Increasing this value
@@ -216,25 +212,27 @@ class MLXGlobalExplainer(GlobalExplainer):
             `partial_range`, the number of unique values is selected. For two-feature
             PDP, the total number of evaluated samples is the multiplication
             of `num_samples`. Default value is 30.
-
         sampling : dict, optional
             If not None, the dataset will be clustered or sampled according to the
             provided technique. 'sampling' is a dictionary containing the technique
             to use and the corresponding parameters. Format is described below:
 
-                - **technique**: Either "cluster" or "random".
-                - **cluster** also requires:
-                    - `eps`: Maximum distance between two samples to be considered
-                      in the same cluster.
-                    - `min_samples`: Minimum number of samples to include in each
-                      cluster.
-                - **random** also requires:
-                    - 'n_samples': Number of samples to return.
+            - `technique`: Either "cluster" or "random".
+            - `cluster` also requires:
+
+                - `eps`: Maximum distance between two samples to be considered
+                  in the same cluster.
+                - `min_samples`: Minimum number of samples to include in each
+                  cluster.
+
+            - `random` also requires:
+
+                - 'n_samples': Number of samples to return.
 
             Default value is `None` (no sampling).
 
-        Return
-        ------
+        Returns
+        -------
         :class:MLXPartialDependencies
             `MLXPartialDependencies` object.
 
@@ -313,40 +311,41 @@ class MLXGlobalExplainer(GlobalExplainer):
         ----------
         feature : str
             Feature name to explain.
-
         partial_range : tuple, optional
             Min/max percentile values to consider for the ALE from the
             feature's train distribution. Must be between 0.0 and 1.0.
             By default `partial = (0.05, 0.95)`.
-
         num_samples : int, optional
             Maximum number of samples to generate for each feature within the
             `partial_range` of its value distribution. Increasing this value
             generates more points to evaluate, but increases the explanation
             time. If there are fewer unique values for a feature within the
             `partial_range`, the number of unique values is selected.
-
         sampling : dict, optional
             If not `None`, the dataset is clustered or sampled according to the
             provided technique. `sampling` is a dictionary containing the technique
             to use and the corresponding parameters. The format is:
 
-                - **technique**: Can be either "cluster" or "random".
-                - **cluster** also requires:
-                    - `eps`: Maximum distance between two samples to be considered
-                      in the same cluster.
-                    - `min_samples`: Minimum number of samples to include in each
-                      cluster.
-                - **random** also requires:
-                    - `n_samples`: Number of samples to return.
+            - `technique`: Can be either "cluster" or "random".
+            - `cluster` also requires:
+
+                - `eps`: Maximum distance between two samples to be considered
+                  in the same cluster.
+                - `min_samples`: Minimum number of samples to include in each
+                  cluster.
+
+            - `random` also requires:
+
+                - `n_samples`: Number of samples to return.
 
             Defaults to `None` (no sampling).
 
         corr_threshold : float, optional
-             Value between 0.0 and 1.0 for which a feature is considered highly correlated with another feature (Default = 0.7).
+             Value between 0.0 and 1.0 for which a feature is considered highly correlated with
+             another feature (Default = 0.7).
 
-        Return
-        ------
+        Returns
+        -------
         :class:MLXAccumulatedLocalEffects
             `AccumulatedLocalEffects` explanation object.
 
@@ -434,25 +433,29 @@ class MLXGlobalExplainer(GlobalExplainer):
         importance explainer, text datasets use the aggregate local explainer.
 
         Supported configuration options:
-            For tabular datasets:
-                client: Currently only allowed to be None to disable parallelization.
-                random_state: None, int, or instance of Randomstate.
-            For text datasets:
-                surrogate_model: Surrogate model to use. Can be 'linear' or 'decision_tree'.
-                num_samples: Number of generated samples to fit the surrogate model. Int.
-                exp_sorting: Feature importance sorting. Can be 'absolute' or 'ordered'.
-                scale_weight: Normalizes the feature importance coefficients from LIME to sum to one.
-                client: Currently only allowed to be None to disable parallelization.
-                batch_size: Number of local explanations per Dask worker.
-                random_state: None, int, or instance of Randomstate.
+
+        - For tabular datasets:
+
+            - `client`: Currently only allowed to be None to disable parallelization.
+            - `random_state`: None, int, or instance of Randomstate.
+
+        - For text datasets:
+
+            - `surrogate_model`: Surrogate model to use. Can be 'linear' or 'decision_tree'.
+            - `num_samples`: Number of generated samples to fit the surrogate model. Int.
+            - `exp_sorting`: Feature importance sorting. Can be 'absolute' or 'ordered'.
+            - `scale_weight`: Normalizes the feature importance coefficients from LIME to sum to one.
+            - `client`: Currently only allowed to be None to disable parallelization.
+            - `batch_size`: Number of local explanations per Dask worker.
+            - `random_state`: None, int, or instance of Randomstate.
 
         Parameters
         ----------
         kwargs : dict
             Keyword parameter dictionary.
 
-        Return
-        ------
+        Returns
+        -------
         MLXGlobalExplainer
             the modified instance (self)
 
@@ -505,8 +508,8 @@ class MLXGlobalExplainer(GlobalExplainer):
         kwargs : dict
             Keyword parameter dictionary.
 
-        Return
-        ------
+        Returns
+        -------
         MLXGlobalExplainer
             the modified instance (self)
         """
@@ -532,15 +535,16 @@ class MLXGlobalExplainer(GlobalExplainer):
         configuration parameters in kwargs. Only supports tabular datasets.
 
         Supported configuration options:
-            client: Currently only supports 'None' to disable parallelization.
+
+        - client: Currently only supports 'None' to disable parallelization.
 
         Parameters
         ----------
         kwargs : dict
             Keyword parameter dictionary.
 
-        Return
-        ------
+        Returns
+        -------
         MLXGlobalExplainer
             the modified instance (self)
         """
@@ -564,8 +568,8 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
         Displays detailed information about the feature importance explainer.
 
-        Return
-        ------
+        Returns
+        -------
         str
             HTML object representing the explainer summary.
 
@@ -579,8 +583,8 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
         Displays detailed information about the partial dependence explainer.
 
-        Return
-        ------
+        Returns
+        -------
         str
             HTML object representing the explainer summary.
         """
@@ -593,8 +597,8 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
         Displays detailed information about the accumulated local effects explainer.
 
-        Return
-        ------
+        Returns
+        -------
         str
             HTML object representing the explainer summary.
         """
@@ -605,13 +609,13 @@ class MLXGlobalExplainer(GlobalExplainer):
 
     def _init_feature_importance(self, **kwargs):
         """
-        Internal function to initializes the feature importance explainer. Tabular datasets
+        Internal function to initialize the feature importance explainer. Tabular datasets
         use the feature permutation importance explainer, text datasets use the aggregate local
         explainer.
 
         Parameters
         ----------
-        **kwargs : dict
+        kwargs : dict
             Keyword parameter dictionary.
         """
         if self.mode == "regression":
@@ -645,7 +649,7 @@ class MLXGlobalExplainer(GlobalExplainer):
 
         Parameters
         ----------
-        **kwargs : dict
+        kwargs : dict
             Keyword parameter dictionary.
         """
         if self.mode == "regression":
@@ -666,7 +670,7 @@ class MLXGlobalExplainer(GlobalExplainer):
 
         Parameters
         ----------
-        **kwargs : dict
+        kwargs : dict
             Keyword parameter dictionary.
         """
         if self.mode == "regression":
@@ -726,8 +730,8 @@ class MLXFeatureDependenceExplanation(ABC):
         show_median : bool, optional
             If True, a median line is included in the ICE explanation plot. Default is True.
 
-        Return
-        ------
+        Returns
+        -------
         str
             Plotly HTML object containing a line chart, heat map, or violin plot for this feature dependence explanation
         """
@@ -737,8 +741,8 @@ class MLXFeatureDependenceExplanation(ABC):
         """
         Returns the raw explanation data as a pandas.DataFrame.
 
-        Return
-        ------
+        Returns
+        -------
         pandas.DataFrame
             DataFrame containing the raw PDP explanation data.
         """
@@ -749,8 +753,8 @@ class MLXFeatureDependenceExplanation(ABC):
         Extracts the raw explanation and evaluation data from the explanation object
         (Used to generate the visualizations).
 
-        Return
-        ------
+        Returns
+        -------
         dict
             Dictionary containing the raw explanation/evaluation data.
         """
@@ -809,8 +813,8 @@ class MLXPartialDependencies(MLXFeatureDependenceExplanation):
         show_median : bool, optional
             If `True`, a median line is included in the ICE explanation plot. Default is `True`.
 
-        Return
-        ------
+        Returns
+        -------
         str
             Plotly HTML object containing a line chart, heat map, or violin plot for this feature dependence explanation
         """
@@ -874,8 +878,8 @@ class MLXAccumulatedLocalEffects(MLXFeatureDependenceExplanation):
         show_median : bool, optional
             If `True`, a median line is included in the ALE explanation plot. Default is `True`.
 
-        Return
-        ------
+        Returns
+        -------
         str
             Plotly HTML object containing a line chart, heat map, or violin plot for this feature dependence explanation
         """
@@ -928,31 +932,35 @@ class FeatureImportance:
         mode : str
             Type of visualization to generate. Certain visualization modes are only supported for either text or
             tabular datasets. Supported options:
-                - **bar**: Generates a horizontal bar chart for the most important features (text and tabular).
-                - **stacked**: Generates a stacked horizontal bar chart for the most important features (text and tabular).
-                - **box_plot**: Generates a box plot for the most important features, which provides more information
-                  about the explanation over the different iterations of the feature permutation importance
-                  algorithm (tabular only).
-                - **detailed**: Generates a scatter plot for the most important features, providing even more
-                  information about the explanation over the different iterations of the Feature Permutation
-                  Importance algorithm (tabular only).
-                - **heatmap**: Generates a heatmap representing the average feature/word importance over multiple
-                  local explanations (aggregates local explanations). Average feature importance is measured by
-                  the fraction of local explanations where a given feature was assigned a given importance
-                  (text only).
-                - **wordcloud**: Generates a wordcloud from the average feature importance. Features/words with
-                  higher importance are larger than features/words with lower importance (text only).
+
+            - `bar`: Generates a horizontal bar chart for the most important features (text and tabular).
+            - `stacked`: Generates a stacked horizontal bar chart for the most important features (text and tabular).
+            - `box_plot`: Generates a box plot for the most important features, which provides more information
+              about the explanation over the different iterations of the feature permutation importance
+              algorithm (tabular only).
+            - `detailed`: Generates a scatter plot for the most important features, providing even more
+              information about the explanation over the different iterations of the Feature Permutation
+              Importance algorithm (tabular only).
+            - `heatmap`: Generates a heatmap representing the average feature/word importance over multiple
+              local explanations (aggregates local explanations). Average feature importance is measured by
+              the fraction of local explanations where a given feature was assigned a given importance
+              (text only).
+            - `wordcloud`: Generates a wordcloud from the average feature importance. Features/words with
+              higher importance are larger than features/words with lower importance (text only).
+
             Default value is "bar" for tabular and "wordcloud" for text.
         show : str
             (text only) Secondary visualization mode for configuring the visualization.
             Can be one of:
-                - **absolute**: The absolute value of feature importances are shown (i.e., a feature that is highly
-                  important towards or against the target label is considered important).
-                - **posneg**: Shows both the positive and negative global feature attributions. For bar, the features
-                  are ordered based on their absolute feature importance (sum of pos/neg) and a dual bar chart shows
-                  the fraction of local explanations where the feature contributed both towards and against the
-                  corresponding label. For wordcloud, two wordclouds are generated for the positive and negative feature
-                  importances. Only valid for mode=bar and mode=wordcloud. `mode=heatmap` defaults to `show=absolute`.
+
+            - `absolute`: The absolute value of feature importances are shown (i.e., a feature that is highly
+              important towards or against the target label is considered important).
+            - `posneg`: Shows both the positive and negative global feature attributions. For bar, the features
+              are ordered based on their absolute feature importance (sum of pos/neg) and a dual bar chart shows
+              the fraction of local explanations where the feature contributed both towards and against the
+              corresponding label. For wordcloud, two wordclouds are generated for the positive and negative feature
+              importances. Only valid for mode=bar and mode=wordcloud. `mode=heatmap` defaults to `show=absolute`.
+
         labels : tuple, list, int, bool, str
             (text only) Label indices to visualize. If `None`, all of the labels that the explanation was generated for
             will be visualized. By default None.
@@ -968,11 +976,11 @@ class FeatureImportance:
             (tabular only). Allows the user to visualize a subset of the top-N most important features from the explainer.
             If `n_features` is `None` or greater than the total number of features, all features are shown. If
             `n_features` is not an `int` or <= 0, an exception is thrown.
-        **kwargs : dict
+        kwargs : dict
             Keyword arguments for configuring the wordclouds.
 
-        Return
-        ------
+        Returns
+        -------
         str, list of wordcloud
             HTML string for the visualization or list of generated wordcloud objects if `return_wordcloud=True`,
             two per label (+/-).
@@ -1008,8 +1016,8 @@ class FeatureImportance:
         """
         Returns the raw global explanation data only.
 
-        Return
-        ------
+        Returns
+        -------
         dict
             Dictionary containing raw explanation data.
         """
@@ -1020,8 +1028,8 @@ class FeatureImportance:
         Extracts the raw explanation and evaluation data from the explanation object
         (Used to generate the visualizations).
 
-        Return
-        ------
+        Returns
+        -------
         dict
             Dictionary containing the raw explanation/evaluation data.
         """
