@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from mlx import LimeExplainer
@@ -9,12 +9,8 @@ from mlx import FDExplainer, AleExplainer
 from mlx import PermutationImportance
 from ads.common import utils
 from ads.dataset.helper import is_text_data
-from ads.environment import ml_runtime
 from mlx.whatif import WhatIf
 import pandas as pd
-import os.path
-import errno
-import os
 
 
 def _reset_index(x):
