@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 """
@@ -9,50 +9,51 @@ The ADS accessor for the Pandas DataFrame.
 The accessor will be initialized with the pandas object the user is interacting with.
 
 Examples
-    --------
-    >>> from ads.feature_engineering.accessor.dataframe_accessor import ADSDataFrameAccessor
+--------
+>>> from ads.feature_engineering.accessor.dataframe_accessor import ADSDataFrameAccessor
     >>> from ads.feature_engineering.feature_type.continuous import Continuous
     >>> from ads.feature_engineering.feature_type.creditcard import CreditCard
     >>> from ads.feature_engineering.feature_type.string import String
     >>> from ads.feature_engineering.feature_type.base import Tag
-    >>> df = pd.DataFrame({'Name': ['Alex'], 'CreditCard': ["4532640527811543"]})
-    >>> df.ads.feature_type
-    {'Name': ['string'], 'Credit Card': ['string']}
-    >>> df.ads.feature_type_description
-              Column   Feature Type                        Description
-    ------------------------------------------------------------------
-    0           Name         string    Type representing string values.
-    1    Credit Card         string    Type representing string values.
-    >>> df.ads.default_type
-    {'Name': 'string', 'Credit Card': 'string'}
-    >>> df.ads.feature_type = {'Name':['string', Tag('abc')]}
-    >>> df.ads.tags
-    {'Name': ['abc']}
-    >>> df.ads.feature_type = {'Credit Card':['credit_card']}
-    >>> df.ads.feature_select(include=['credit_card'])
-                        Credit Card
-    -------------------------------
-    0	          4532640527811543
+>>> df = pd.DataFrame({'Name': ['Alex'], 'CreditCard': ["4532640527811543"]})
+>>> df.ads.feature_type
+{'Name': ['string'], 'Credit Card': ['string']}
+>>> df.ads.feature_type_description
+          Column   Feature Type                        Description
+------------------------------------------------------------------
+0           Name         string    Type representing string values.
+1    Credit Card         string    Type representing string values.
+>>> df.ads.default_type
+{'Name': 'string', 'Credit Card': 'string'}
+>>> df.ads.feature_type = {'Name':['string', Tag('abc')]}
+>>> df.ads.tags
+{'Name': ['abc']}
+>>> df.ads.feature_type = {'Credit Card':['credit_card']}
+>>> df.ads.feature_select(include=['credit_card'])
+                    Credit Card
+-------------------------------
+0	          4532640527811543
 """
 
 from typing import Any, Dict, List, Union
 
 import numpy as np
 import pandas as pd
+from ads.common.utils import DATA_SCHEMA_MAX_COL_NUM
+from ads.data_labeling.mixin.data_labeling import DataLabelingAccessMixin
+from ads.dbmixin.db_pandas_accessor import DBAccessMixin
+from ads.feature_engineering import schema
 from ads.feature_engineering.accessor.mixin.eda_mixin import EDAMixin
-from ads.feature_engineering.feature_type.base import FeatureType
 from ads.feature_engineering.accessor.mixin.feature_types_mixin import (
     ADSFeatureTypesMixin,
 )
-from ads.oracledb.mixin.oracle_db import OracleDBAccessMixin
-from ads.data_labeling.mixin.data_labeling import DataLabelingAccessMixin
+from ads.feature_engineering.feature_type.base import FeatureType
 from pandas.core.dtypes.common import is_list_like
-from ads.feature_engineering import schema
 
 
 @pd.api.extensions.register_dataframe_accessor("ads")
 class ADSDataFrameAccessor(
-    ADSFeatureTypesMixin, EDAMixin, OracleDBAccessMixin, DataLabelingAccessMixin
+    ADSFeatureTypesMixin, EDAMixin, DBAccessMixin, DataLabelingAccessMixin
 ):
     """ADS accessor for the Pandas DataFrame.
 
@@ -61,8 +62,6 @@ class ADSDataFrameAccessor(
     columns: List[str]
         The column labels of the DataFrame.
 
-    Attributes
-    ----------
     tags(self) -> Dict[str, str]
         Gets the dictionary of user defined tags for the dataframe.
     default_type(self) -> Dict[str, str]
@@ -76,10 +75,7 @@ class ADSDataFrameAccessor(
     -------
     sync(self, src: Union[pd.DataFrame, pd.Series]) -> pd.DataFrame
         Syncs feature types of current DataFrame with that from src.
-    feature_select(self,
-                    include: List[Union[FeatureType, str]] = None,
-                    exclude: List[Union[FeatureType, str]] = None
-                    ) -> pd.DataFrame
+    feature_select(self, include: List[Union[FeatureType, str]] = None, exclude: List[Union[FeatureType, str]] = None) -> pd.DataFrame
         Gets the list of registered feature types in a DataFrame format.
     help(self, prop: str = None) -> None
         Provids docstring for affordable methods and properties.
@@ -121,7 +117,8 @@ class ADSDataFrameAccessor(
 
         Raises
         ------
-        ValueError: If provided DataFrame has duplicate columns.
+        ValueError
+            If provided DataFrame has duplicate columns.
         """
         if len(set(pandas_obj.columns)) != len(pandas_obj.columns):
             raise ValueError(
@@ -168,7 +165,7 @@ class ADSDataFrameAccessor(
         Returns
         -------
         Dict[str, List[str]]
-            The map of clumns and associated default tags.
+            The map of columns and associated default tags.
         """
         return {self._obj[col].name: self._obj[col].ads.tags for col in self._obj}
 
@@ -191,7 +188,7 @@ class ADSDataFrameAccessor(
         Returns
         -------
         Dict[str, List[str]]
-            The dictionary where key is column name and value is list of associated feture type
+            The dictionary where key is column name and value is list of associated feature type
             names.
         """
         return {col.name: col.ads.feature_type for _, col in self._obj.items()}
@@ -203,13 +200,14 @@ class ADSDataFrameAccessor(
         Returns
         -------
         :class:`pandas.DataFrame`
+
         Examples
         ________
         >>> df.ads.feature_type_description()
-                      Column   Feature Type                         Description
-            -------------------------------------------------------------------
-            0           City         string    Type representing string values.
-            1   Phone Number         string    Type representing string values.
+                  Column   Feature Type                         Description
+        -------------------------------------------------------------------
+        0           City         string    Type representing string values.
+        1   Phone Number         string    Type representing string values.
         """
         result_df = pd.DataFrame([], columns=["Column", "Feature Type", "Description"])
         for col in self._obj:
@@ -248,7 +246,7 @@ class ADSDataFrameAccessor(
 
         Parameters
         ----------
-        src : (`pd.DataFrame` | `pd.Series`)
+        src: `pd.DataFrame` | `pd.Series`
             The source to sync from.
 
         Returns
@@ -267,14 +265,14 @@ class ADSDataFrameAccessor(
 
         Parameters
         ----------
-        target_types : list
+        target_types: list
             A list of target feature types, can be either feature type names of
             feature type class.
 
         Returns:
         -------
-            List[str]
-                The list of columns names.
+        List[str]
+            The list of columns names.
         """
         columns = []
         target_types = (
@@ -299,15 +297,17 @@ class ADSDataFrameAccessor(
 
         Parameters
         ----------
-        include: (List[Union[FeatureType, str]], optional):
+        include: List[Union[FeatureType, str]], optional
             Defaults to None. A list of FeatureType subclass or str to be included.
-        exclude: (List[Union[FeatureType, str]], optional):
+        exclude: List[Union[FeatureType, str]], optional
             Defaults to None. A list of FeatureType subclass or str to be excluded.
 
         Raises
         ------
-        ValueError: If both of include and exclude are empty
-        ValueError: If include and exclude are used simultaneously
+        ValueError
+            If both of include and exclude are empty
+        ValueError
+            If include and exclude are used simultaneously
 
         Returns
         -------
@@ -401,10 +401,15 @@ class ADSDataFrameAccessor(
             raise ValueError(f"Column {col} is not found.")
         self._obj[col].ads._remove_feature_type(feature_type)
 
-    def model_schema(self):
+    def model_schema(self, max_col_num: int = DATA_SCHEMA_MAX_COL_NUM):
         """
         Generates schema from the dataframe.
 
+        Parameters
+        ----------
+        max_col_num : int, optional. Defaults to 1000
+            The maximum column size of the data that allows to auto generate schema.
+
         Examples
         --------
         >>> df = pd.read_csv('./orcl_attrition.csv', usecols=['Age', 'Attrition'])
@@ -468,9 +473,18 @@ class ADSDataFrameAccessor(
         -------
         ads.feature_engineering.schema.Schema
             data schema.
-        """
-        sc = schema.Schema()
 
+        Raises
+        ------
+        ads.feature_engineering.schema.DataSizeTooWide
+            If the number of columns of input data exceeds `max_col_num`.
+        """
+        if max_col_num and len(self._obj.columns) > max_col_num:
+            raise schema.DataSizeTooWide(
+                data_col_num=len(self._obj.columns), max_col_num=max_col_num
+            )
+
+        sc = schema.Schema()
         for col in self._obj.columns:
             domain = schema.Domain()
             try:
