@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 """
@@ -75,7 +75,6 @@ from ads.feature_engineering.feature_type.text import Text
 from ads.feature_engineering.feature_type.unknown import Unknown
 from ads.feature_engineering.feature_type.discrete import Discrete
 from ads.feature_engineering import exceptions
-from ads.feature_engineering.feature_type.adsstring.string import ADSString
 
 logger = logging.getLogger(__name__)
 
@@ -186,7 +185,6 @@ class FeatureTypeManager:
         Text,
         Unknown,
         Discrete,
-        ADSString,
     ]
     _name_to_type_map = {tp.name: tp for tp in _default_registered_type}
 
