@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from abc import ABC, abstractmethod
-from dataclasses import asdict, dataclass, field
-from typing import Dict, List, Union
+from dataclasses import dataclass, field
+from typing import Dict, List
 
 import yaml
 from ads.common.helper import Serializable
@@ -21,14 +21,13 @@ except:
 import json
 import os
 from os import path
-from typing import Union
 
 import fsspec
 import yaml
 from cerberus import Validator
-from yaml import dump, load
 import sys
 from string import Template
+from asteval import Interpreter
 
 
 SCHEMA_VALIDATOR_NAME = "data_schema.json"
@@ -44,6 +43,15 @@ class SchemaSizeTooLarge(ValueError):
         )
 
 
+class DataSizeTooWide(ValueError):
+    def __init__(self, data_col_num: int, max_col_num: int):
+        super().__init__(
+            f"The data has `{data_col_num}` columns and "
+            f"the maximum allowable number of columns is `{max_col_num}`. "
+            "Increase allowable number of columns by setting a larger max_col_num. It will take longer time to prepare."
+        )
+
+
 @dataclass(repr=False)
 class Expression(Serializable):
     """
@@ -74,7 +82,21 @@ class Expression(Serializable):
     language: str = "python"
 
     def evaluate(self, **kwargs):
-        pass
+        if self.language.lower() != "python":
+            raise Exception(
+                f"Evaluation not supported for language ${self.language}. Supported language: python"
+            )
+
+        exp = Template(self.expression)
+        final_expression = None
+        try:
+            final_expression = exp.substitute(kwargs)
+        except:
+            raise Exception(
+                "Error substituting the value into the expression. Check if the variable in the expression matches the parameter names passed to evaluate method"
+            )
+        aeval = Interpreter()
+        return aeval(final_expression)
 
     def __post_init__(self):
         if not self.expression or not self.language:
