@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import importlib
@@ -43,17 +43,21 @@ from optuna import samplers  # NOQA
 from optuna import type_checking  # NOQA
 from optuna import study as study_module  # NOQA
 
+import sklearn
+
 with try_import() as _imports:
     from sklearn.base import BaseEstimator, clone, is_classifier
-    from sklearn.metrics import check_scoring
     from sklearn.model_selection import BaseCrossValidator  # NOQA
     from sklearn.model_selection import check_cv, cross_validate
     from sklearn.pipeline import Pipeline, make_pipeline
     from sklearn.utils import check_random_state
     from sklearn.exceptions import NotFittedError
 
-if not _imports.is_successful():
-    BaseEstimator = object  # NOQA
+    try:
+        from sklearn.metrics import check_scoring
+    except:
+        from sklearn.metrics.scorer import check_scoring
+
 
 if type_checking.TYPE_CHECKING:  # pragma: no cover
     from typing import Any  # NOQA
