@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
+
 try:
     from ads.jobs.builders.runtimes.python_runtime import (
         PythonRuntime,
@@ -20,7 +21,7 @@ try:
     )
     from ads.jobs.builders.infrastructure.dataflow import DataFlow, DataFlowRun
 except AttributeError as e:
-    import oci
+    import oci.data_science
     import logging
 
     logger = logging.getLogger(__name__)
