@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 from typing import List, Union
 
@@ -31,7 +31,7 @@ class Job(Builder):
     Here is an example for creating and running a job:
 
     .. code-block:: python
-        
+
         from ads.jobs import Job, DataScienceJob, PythonRuntime
         # Define an OCI Data Science job to run a python script
         job = (
@@ -47,7 +47,7 @@ class Job(Builder):
                 .with_log_id("<log_ocid>")
             )
             .with_runtime(
-                PythonRuntime()
+                ScriptRuntime()
                 .with_source("oci://bucket_name@namespace/path/to/script.py")
                 .with_service_conda("tensorflow26_p37_cpu_v2")
                 .with_environment_variable(ENV="value")
