@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 """Contains classes for conversion between ADS runtime and OCI Data Science Job implementation.
 This module is for ADS developers only.
@@ -28,7 +28,11 @@ from ads.jobs.builders.runtimes.python_runtime import (
     GitPythonRuntime,
 )
 from ads.jobs.builders.runtimes.container_runtime import ContainerRuntime
-from ads.jobs.builders.runtimes.artifact import ScriptArtifact, NotebookArtifact
+from ads.jobs.builders.runtimes.artifact import (
+    ScriptArtifact,
+    NotebookArtifact,
+    PythonArtifact,
+)
 from ads.jobs.builders.infrastructure.utils import get_value
 
 
@@ -560,10 +564,71 @@ class ScriptRuntimeHandler(CondaRuntimeHandler):
         return spec
 
 
-class PythonRuntimeHandler(ScriptRuntimeHandler):
+class PythonRuntimeHandler(CondaRuntimeHandler):
     """Runtime Handler for PythonRuntime"""
 
     RUNTIME_CLASS = PythonRuntime
+    PATH_DELIMITER = ":"
+    CONST_JOB_ENTRYPOINT = "JOB_RUN_ENTRYPOINT"
+    CONST_CODE_ENTRYPOINT = "CODE_ENTRYPOINT"
+    CONST_ENTRY_FUNCTION = "ENTRY_FUNCTION"
+    CONST_PYTHON_PATH = "PYTHON_PATH"
+    CONST_OUTPUT_DIR = "OUTPUT_DIR"
+    CONST_OUTPUT_URI = "OUTPUT_URI"
+    CONST_WORKING_DIR = "WORKING_DIR"
+
+    SPEC_MAPPINGS = {
+        PythonRuntime.CONST_ENTRYPOINT: CONST_CODE_ENTRYPOINT,
+        PythonRuntime.CONST_ENTRY_FUNCTION: CONST_ENTRY_FUNCTION,
+        PythonRuntime.CONST_PYTHON_PATH: CONST_PYTHON_PATH,
+        PythonRuntime.CONST_OUTPUT_DIR: CONST_OUTPUT_DIR,
+        PythonRuntime.CONST_OUTPUT_URI: CONST_OUTPUT_URI,
+        PythonRuntime.CONST_WORKING_DIR: CONST_WORKING_DIR,
+    }
+
+    def _translate_artifact(self, runtime: PythonRuntime):
+        return PythonArtifact(runtime.script_uri, runtime)
+
+    def _translate_env(self, runtime: PythonRuntime) -> dict:
+        envs = super()._translate_env(runtime)
+        envs.update(
+            self._translate_specs(runtime, self.SPEC_MAPPINGS, self.PATH_DELIMITER)
+        )
+
+        if runtime.entrypoint:
+            envs[self.CONST_CODE_ENTRYPOINT] = runtime.entrypoint
+        else:
+            envs[self.CONST_CODE_ENTRYPOINT] = os.path.basename(runtime.script_uri)
+
+        envs[self.CONST_JOB_ENTRYPOINT] = PythonArtifact.CONST_DRIVER_SCRIPT
+        return envs
+
+    def _extract_envs(self, dsc_job) -> dict:
+        """Extract the runtime specification from environment variables.
+
+        Parameters
+        ----------
+        dsc_job : DSCJob or oci.datascience.models.Job
+            The data science job containing runtime information.
+
+        Returns
+        -------
+        dict
+            A runtime specification dictionary for initializing a runtime.
+        """
+        spec = super()._extract_envs(dsc_job)
+        envs = spec.pop(PythonRuntime.CONST_ENV_VAR, {})
+        if self.CONST_CODE_ENTRYPOINT not in envs:
+            raise IncompatibleRuntime()
+        envs.pop(PythonRuntimeHandler.CONST_JOB_ENTRYPOINT)
+        spec.update(self._extract_specs(envs, self.SPEC_MAPPINGS))
+        if PythonRuntime.CONST_PYTHON_PATH in spec:
+            spec[PythonRuntime.CONST_PYTHON_PATH] = spec[
+                PythonRuntime.CONST_PYTHON_PATH
+            ].split(self.PATH_DELIMITER)
+        if envs:
+            spec[PythonRuntime.CONST_ENV_VAR] = envs
+        return spec
 
 
 class NotebookRuntimeHandler(CondaRuntimeHandler):
@@ -625,10 +690,11 @@ class GitPythonRuntimeHandler(CondaRuntimeHandler):
     CONST_GIT_BRANCH = "GIT_BRANCH"
     CONST_GIT_COMMIT = "GIT_COMMIT"
     CONST_GIT_CODE_DIR = "CODE_DIR"
-    CONST_GIT_ENTRYPOINT = "GIT_ENTRYPOINT"
-    CONST_GIT_ENTRY_FUNCTION = "ENTRY_FUNCTION"
     CONST_GIT_SSH_SECRET_ID = "GIT_SECRET_OCID"
     CONST_SKIP_METADATA = "SKIP_METADATA_UPDATE"
+
+    CONST_ENTRYPOINT = "GIT_ENTRYPOINT"
+    CONST_ENTRY_FUNCTION = "ENTRY_FUNCTION"
     CONST_PYTHON_PATH = "PYTHON_PATH"
     CONST_OUTPUT_DIR = "OUTPUT_DIR"
     CONST_OUTPUT_URI = "OUTPUT_URI"
@@ -637,8 +703,8 @@ class GitPythonRuntimeHandler(CondaRuntimeHandler):
         GitPythonRuntime.CONST_GIT_URL: CONST_GIT_URL,
         GitPythonRuntime.CONST_BRANCH: CONST_GIT_BRANCH,
         GitPythonRuntime.CONST_COMMIT: CONST_GIT_COMMIT,
-        GitPythonRuntime.CONST_ENTRYPOINT: CONST_GIT_ENTRYPOINT,
-        GitPythonRuntime.CONST_ENTRY_FUNCTION: CONST_GIT_ENTRY_FUNCTION,
+        GitPythonRuntime.CONST_ENTRYPOINT: CONST_ENTRYPOINT,
+        GitPythonRuntime.CONST_ENTRY_FUNCTION: CONST_ENTRY_FUNCTION,
         GitPythonRuntime.CONST_PYTHON_PATH: CONST_PYTHON_PATH,
         GitPythonRuntime.CONST_GIT_SSH_SECRET_ID: CONST_GIT_SSH_SECRET_ID,
         GitPythonRuntime.CONST_OUTPUT_DIR: CONST_OUTPUT_DIR,
@@ -705,7 +771,7 @@ class GitPythonRuntimeHandler(CondaRuntimeHandler):
         spec = super()._extract_envs(dsc_job)
         envs = spec.pop(CondaRuntime.CONST_ENV_VAR, {})
 
-        if self.CONST_GIT_URL not in envs or self.CONST_GIT_ENTRYPOINT not in envs:
+        if self.CONST_GIT_URL not in envs or self.CONST_ENTRYPOINT not in envs:
             raise IncompatibleRuntime()
         spec.update(self._extract_specs(envs, self.SPEC_MAPPINGS))
         if GitPythonRuntime.CONST_PYTHON_PATH in spec:
@@ -823,8 +889,8 @@ class DataScienceJobRuntimeManager(RuntimeHandler):
         ContainerRuntimeHandler,
         GitPythonRuntimeHandler,
         NotebookRuntimeHandler,
-        ScriptRuntimeHandler,
         PythonRuntimeHandler,
+        ScriptRuntimeHandler,
     ]
 
     def translate(self, runtime) -> dict:
