@@ -6,6 +6,7 @@
 from __future__ import annotations
 
 import json
+import os
 from typing import Any, Dict
 
 from ads.jobs.builders.runtimes.base import Runtime
@@ -171,10 +172,133 @@ class ScriptRuntime(CondaRuntime):
         return self.set_spec(self.CONST_ENTRYPOINT, entrypoint)
 
 
-class PythonRuntime(ScriptRuntime):
-    """Represents a job runtime with Python code
-    Currently this is the same as ScriptRuntime
-    """
+class _PythonRuntimeMixin(Runtime):
+    CONST_OUTPUT_DIR = "outputDir"
+    CONST_OUTPUT_URI = "outputUri"
+    CONST_PYTHON_PATH = "pythonPath"
+    CONST_ENTRYPOINT = "entrypoint"
+    CONST_ENTRY_FUNCTION = "entryFunction"
+
+    def with_output(self, output_dir: str, output_uri: str):
+        """Specifies the outputs of the job.
+        The output files in output_dir will be copied to remote output_uri when the job is finished.
+
+        Parameters
+        ----------
+        output_dir : str
+            Path to the output directory in the job run.
+            This path should be a relative path from the working directory.
+            The source code should write all outputs into this directory.
+        output_uri : str
+            The OCI object storage URI prefix for saving the output files.
+            For example, oci://bucket_name@namespace/path/to/directory
+
+        Returns
+        -------
+        self
+            The runtime instance.
+        """
+        self.set_spec(self.CONST_OUTPUT_DIR, output_dir)
+        self.set_spec(self.CONST_OUTPUT_URI, output_uri)
+        return self
+
+    def with_python_path(self, *python_paths):
+        """Specifies additional python paths for running the source code.
+
+        Parameters
+        ----------
+        *python_paths :
+            Additional python path(s) for running the source code.
+            Each path should be a relative path from the working directory.
+
+        Returns
+        -------
+        self
+            The runtime instance.
+        """
+        python_paths = list(python_paths)
+        for path in python_paths:
+            if os.path.isabs(path):
+                raise ValueError(
+                    f"{path} is an absolute path."
+                    "Please specify relative path from the working directory as python path."
+                )
+        return self.set_spec(self.CONST_PYTHON_PATH, python_paths)
+
+    def with_entrypoint(self, path: str, func: str = None):
+        """Specifies the entrypoint for the job.
+        The entrypoint can be a script or a function in a script.
+
+        Parameters
+        ----------
+        script : str
+            The relative path for the script/module starting the job.
+        func : str, optional
+            The function name in the script for starting the job, by default None.
+            If this is not specified, the script will be run with python command in a subprocess.
+
+        Returns
+        -------
+        self
+            The runtime instance.
+        """
+        self.set_spec(self.CONST_ENTRYPOINT, path)
+        self.set_spec(self.CONST_ENTRY_FUNCTION, func)
+        return self
+
+    @property
+    def output_dir(self) -> str:
+        """Directory in the Job run container for saving output files generated in the job"""
+        return self.get_spec(self.CONST_OUTPUT_DIR)
+
+    @property
+    def output_uri(self) -> str:
+        """OCI object storage URI prefix for saving output files generated in the job"""
+        return self.get_spec(self.CONST_OUTPUT_DIR)
+
+    @property
+    def python_path(self):
+        """Additional python paths for running the source code."""
+        return self.get_spec(self.CONST_PYTHON_PATH)
+
+    @property
+    def entry_script(self) -> str:
+        """The path of the entry script"""
+        return self.get_spec(self.CONST_ENTRYPOINT)
+
+    @property
+    def entry_function(self) -> str:
+        """The name of the entry function in the entry script"""
+        return self.get_spec(self.CONST_ENTRY_FUNCTION)
+
+
+class PythonRuntime(ScriptRuntime, _PythonRuntimeMixin):
+    """Represents a job runtime using ADS driver script to run Python code"""
+
+    CONST_WORKING_DIR = "workingDir"
+
+    def with_working_dir(self, working_dir: str):
+        """Specifies the working directory in the job run.
+        By default, the working directory will the directory containing the user code (job artifact directory).
+        This can be changed by specifying a relative path to the job artifact directory.
+
+        Parameters
+        ----------
+        working_dir : str
+            The path of the working directory.
+            This can be a relative path from the job artifact directory.
+
+        Returns
+        -------
+        self
+            The runtime instance.
+        """
+        return self.set_spec(self.CONST_WORKING_DIR, working_dir)
+
+    @property
+    def working_dir(self) -> str:
+        """The working directory for the job run."""
+        return self.get_spec(self.CONST_WORKING_DIR, ".")
 
 
 class NotebookRuntime(CondaRuntime):
@@ -252,17 +376,12 @@ class NotebookRuntime(CondaRuntime):
         return self.set_spec(self.CONST_OUTPUT_URI, output_uri)
 
 
-class GitPythonRuntime(CondaRuntime):
+class GitPythonRuntime(CondaRuntime, _PythonRuntimeMixin):
     """Represents a job runtime with source code from git repository"""
 
     CONST_GIT_URL = "url"
     CONST_BRANCH = "branch"
     CONST_COMMIT = "commit"
-    CONST_ENTRYPOINT = "entrypoint"
-    CONST_ENTRY_FUNCTION = "entryFunction"
-    CONST_OUTPUT_DIR = "outputDir"
-    CONST_OUTPUT_URI = "outputUri"
-    CONST_PYTHON_PATH = "pythonPath"
     CONST_GIT_SSH_SECRET_ID = "gitSecretId"
     CONST_SKIP_METADATA = "skipMetadataUpdate"
 
@@ -341,86 +460,6 @@ class GitPythonRuntime(CondaRuntime):
         """Git commit ID (SHA1 hash)"""
         return self.get_spec(self.CONST_COMMIT)
 
-    def with_entrypoint(self, path: str, func: str = None):
-        """Specifies the entrypoint for the job.
-        The entrypoint can be a script or a function in a script.
-
-        Parameters
-        ----------
-        script : str
-            The relative path for the script/module starting the job.
-        func : str, optional
-            The function name in the script for starting the job, by default None.
-            If this is not specified, the script will be run with python command in a subprocess.
-
-        Returns
-        -------
-        self
-            The runtime instance.
-        """
-        self.set_spec(self.CONST_ENTRYPOINT, path)
-        self.set_spec(self.CONST_ENTRY_FUNCTION, func)
-        return self
-
-    @property
-    def entry_script(self) -> str:
-        """The path of the entry script"""
-        return self.get_spec(self.CONST_ENTRYPOINT)
-
-    @property
-    def entry_function(self) -> str:
-        """The name of the entry function in the entry script"""
-        return self.get_spec(self.CONST_ENTRY_FUNCTION)
-
-    def with_output(self, output_dir: str, output_uri: str):
-        """Specifies the outputs of the job.
-        The outputs will be copied to the object storage bucket when the job is finished.
-
-        Parameters
-        ----------
-        output_dir : str
-            Output directory in the container running the job.
-            The source code should write all output data into this directory.
-        output_uri : str
-            The OCI object storage URI prefix for saving the output files.
-            For example, oci://bucket_name@namespace/path/to/directory
-
-        Returns
-        -------
-        self
-            The runtime instance.
-        """
-        self.set_spec(self.CONST_OUTPUT_DIR, output_dir)
-        self.set_spec(self.CONST_OUTPUT_URI, output_uri)
-        return self
-
-    @property
-    def output_dir(self) -> str:
-        """Directory in the Job run container for saving output files generated in the job"""
-        return self.get_spec(self.CONST_OUTPUT_DIR)
-
-    @property
-    def output_uri(self) -> str:
-        """OCI object storage URI prefix for saving output files generated in the job"""
-        return self.get_spec(self.CONST_OUTPUT_DIR)
-
-    def with_python_path(self, *python_paths):
-        """Specifies additional python paths for running the source code.
-        The root of the Git repository is added to PYTHONPATH by default.
-        Paths specified here will be appended to PYTHONPATH before appending the repository root.
-
-        Parameters
-        ----------
-        *python_paths :
-            Additional python path(s) for running the source code.
-
-        Returns
-        -------
-        self
-            The runtime instance.
-        """
-        return self.set_spec(self.CONST_PYTHON_PATH, list(python_paths))
-
     @staticmethod
     def _serialize_arg(arg: Any) -> str:
         """Serialize the argument.
@@ -467,11 +506,6 @@ class GitPythonRuntime(CondaRuntime):
         kwargs = {k: self._serialize_arg(v) for k, v in kwargs.items()}
         return super().with_argument(*args, **kwargs)
 
-    @property
-    def python_path(self):
-        """Additional python paths for running the source code."""
-        return self.get_spec(self.CONST_PYTHON_PATH)
-
     @property
     def ssh_secret_ocid(self):
         """The OCID of the OCI Vault secret storing the Git SSH key."""
