@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 """This module runs user code from git repository.
 The following environment variables are used:
@@ -80,7 +80,7 @@ class GitManager:
             URL is not specified.
         """
         if not repo_url:
-            raise ValueError("Please specify the URL of Git repository.")
+            raise ValueError("Specify the URL of Git repository.")
         self.repo_url = repo_url
         code_dir = os.environ.get("CODE_DIR")
         # Use default directory if CODE_DIR is set to None or empty string.
@@ -447,28 +447,6 @@ class JobRunner:
                     )
                     self.artifacts.append(f"{bucket_name}@{namespace}/{file_prefix}")
 
-    # def update_job_run_metadata_with_python_api(
-    #     self, client: DataScienceClient, metadata: dict
-    # ) -> None:
-    #     """Updates the metadata of the job run by calling OCI Python API
-    #     This method requires the OCI Python SDK to support Job APIs.
-    #     This method is not used at the moment.
-
-    #     Parameters
-    #     ----------
-    #     client : DataScienceClient
-    #         OCI DataScienceClient
-    #     metadata : dict
-    #         Metadata to be saved as freeform tags.
-    #     """
-    #     tags = json.loads(repr(client.get_job_run(self.job_run_ocid).data)).get(
-    #         "freeform_tags", {}
-    #     )
-    #     tags.update(metadata)
-    #     data = oci.data_science.models.UpdateJobRunDetails(freeform_tags=tags)
-    #     response = client.update_job_run(self.job_run_ocid, update_job_run_details=data)
-    #     print(response.data)
-
     @staticmethod
     def _raise_for_error(response: requests.Response):
         if response.status_code >= 400:
