@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 """
 APIs to interact with Oracle's Model Deployment service.
 
-There are three main classes: ModelDeployment, ModelDeploymentDetails, ModelDeployer
+There are three main classes: ModelDeployment, ModelDeploymentDetails, ModelDeployer.
 
 One creates a ModelDeployment and deploys it under the umbrella of the ModelDeployer class. This way
 multiple ModelDeployments can be unified with one ModelDeployer. The ModelDeployer class also serves
@@ -14,19 +14,26 @@ as the interface to all the deployments. ModelDeploymentDetails holds informatio
 details of a particular deployment, such as how many instances, etc. In this way multiple, independent
 ModelDeployments with the same details can be created using the ModelDeployer class.
 
-Usage:
-    >> from model_deploy.model_deployer import ModelDeployer, ModelDeploymentDetails
-    >> deployer = ModelDeployer("model_dep_conf.yaml")
-    >> deployment_properties = ModelDeploymentProperties('ocid1.datasciencemodel.ocn.reg.xxxxxxxxxxxxxxxxxxxxxxxxx')\
-                            .with_prop('display_name', "My model display name")\
-                            .with_prop("project_id", project_id)\
-                            .with_prop("compartment_id", compartment_id)\
-                            .with_instance_configuration(config={"INSTANCE_SHAPE":"VM.Standard2.1", "INSTANCE_COUNT":"1", 'bandwidth_mbps':10}).build()
-    >> deployment_info = deployer.deploy(deployment_properties, max_wait_time=600, poll_interval=15)
-    >> print(deployment_info.model_deployment_id)
-    >> print(deployment_info.workflow_req_id)
-    >> print(deployment_info.url)
-    >> deployer.list_deployments() # Optionally pass in a status
+Examples
+--------
+>>> from model_deploy.model_deployer import ModelDeployer, ModelDeploymentDetails
+>>> deployer = ModelDeployer("model_dep_conf.yaml")
+>>> deployment_properties = ModelDeploymentProperties(
+...             'ocid1.datasciencemodel.ocn.reg.xxxxxxxxxxxxxxxxxxxxxxxxx')
+...                 .with_prop('display_name', "My model display name")
+...                 .with_prop("project_id", project_id)
+...                 .with_prop("compartment_id", compartment_id)
+...                 .with_instance_configuration(
+...                     config={"INSTANCE_SHAPE":"VM.Standard2.1",
+...                             "INSTANCE_COUNT":"1",
+...                             'bandwidth_mbps':10})
+...                      .build()
+>>> deployment_info = deployer.deploy(deployment_properties,
+...             max_wait_time=600, poll_interval=15)
+>>> print(deployment_info.model_deployment_id)
+>>> print(deployment_info.workflow_req_id)
+>>> print(deployment_info.url)
+>>> deployer.list_deployments() # Optionally pass in a status
 """
 from typing import Union, Dict
 
@@ -45,9 +52,12 @@ class ModelDeployer:
 
     Attributes
     ----------
-    config (dict): ADS auth dictionary for OCI authentication.
-    ds_client (DataScienceClient): data science client
-    ds_composite_client (DataScienceCompositeClient): composite data science client
+    config : dict
+        ADS auth dictionary for OCI authentication.
+    ds_client : DataScienceClient
+        data science client
+    ds_composite_client : DataScienceCompositeClient
+        composite data science client
 
     Methods
     -------
@@ -97,8 +107,8 @@ class ModelDeployer:
         Parameters
         ----------
         properties : ModelDeploymentProperties or dict
-            properties to deploy the model.
-            properties can be None when kwargs are used for specifying properties.
+            Properties to deploy the model.
+            Properties can be None when kwargs are used for specifying properties.
         wait_for_completion : bool
             Flag set for whether to wait for deployment to complete before proceeding.
             Optional, defaults to True.
@@ -142,8 +152,8 @@ class ModelDeployer:
         model_uri : str
             uri to model files, can be local or in cloud storage
         properties : ModelDeploymentProperties or dict
-            properties to deploy the model.
-            properties can be None when kwargs are used for specifying properties.
+            Properties to deploy the model.
+            Properties can be None when kwargs are used for specifying properties.
         wait_for_completion : bool
             Flag set for whether to wait for deployment to complete before proceeding.
             Defaults to True
@@ -196,13 +206,13 @@ class ModelDeployer:
         Parameters
         ----------
         model_deployment_id : str
-            Model deployment OCID
+            Model deployment OCID.
         properties : ModelDeploymentProperties
             An instance of ModelDeploymentProperties or dict to initialize the ModelDeploymentProperties.
             Defaults to None.
         wait_for_completion : bool
             Flag set for whether to wait for deployment to complete before proceeding.
-            Defaults to True
+            Defaults to True.
         max_wait_time : int
             Maximum amount of time to wait in seconds (Defaults to 1200).
         poll_interval : int
@@ -210,7 +220,7 @@ class ModelDeployer:
         kwargs :
             Keyword arguments for initializing ModelDeploymentProperties.
 
-            
+
         Returns
         -------
         ModelDeployment
@@ -266,12 +276,10 @@ class ModelDeployer:
         model_deployment_id : str
             Model deployment OCID
 
-
         Returns
         -------
         str
             The state of the deployment
-
         """
 
         model_deployment = self.get_model_deployment(model_deployment_id)
@@ -289,7 +297,7 @@ class ModelDeployer:
         Parameters
         ----------
         model_deployment_id : str
-            Model deployment OCID
+            Model deployment OCID.
         wait_for_completion : bool
             Wait for deletion to complete. Defaults to True.
         max_wait_time : int
@@ -300,7 +308,7 @@ class ModelDeployer:
 
         Returns
         -------
-            A ModelDeployment instance that was deleted
+        A ModelDeployment instance that was deleted
 
         """
         try:
@@ -328,8 +336,6 @@ class ModelDeployer:
             An ValueError will be raised if root compartment ID cannot be determined.
         kwargs :
             The values are passed to oci.data_science.DataScienceClient.list_model_deployments.
-        **kwargs :
-            
 
         Returns
         -------
@@ -346,7 +352,7 @@ class ModelDeployer:
             compartment_id = self.client_manager.default_compartment_id()
         if not compartment_id:
             raise ValueError(
-                "Unable to determine compartment ID from environment. Please specify compartment_id."
+                "Unable to determine compartment ID from environment. Specify compartment_id."
             )
 
         if isinstance(status, State):
@@ -360,7 +366,10 @@ class ModelDeployer:
             self.ds_client.list_model_deployments, compartment_id, **kwargs
         ).data
 
-        return [ModelDeployment(deployment, config=self.config) for deployment in deployments]
+        return [
+            ModelDeployment(deployment, config=self.config)
+            for deployment in deployments
+        ]
 
     def show_deployments(
         self,
@@ -379,7 +388,6 @@ class ModelDeployer:
             Defaults to the compartment set in the environment variable "NB_SESSION_COMPARTMENT_OCID".
             If "NB_SESSION_COMPARTMENT_OCID" is not set, the root compartment ID will be used.
             An ValueError will be raised if root compartment ID cannot be determined.
-            
 
         Returns
         -------
@@ -390,14 +398,12 @@ class ModelDeployer:
         ------
         ValueError
             If compartment_id is not specified and cannot be determined from the environment.
-
-
         """
         if not compartment_id:
             compartment_id = self.client_manager.default_compartment_id()
         if not compartment_id:
             raise ValueError(
-                "Unable to determine compartment ID from environment. Please specify compartment_id."
+                "Unable to determine compartment ID from environment. Specify compartment_id."
             )
 
         if type(status) == str or status == None:
