@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 from typing import Any, Optional, Union
 import oci.data_science.models as data_science_models
@@ -19,9 +19,12 @@ class ModelDeploymentProperties(
 
     Attributes
     ----------
-    swagger_types (dict): The property names and the corresponding types of OCI ModelDeployment model.
-    model_id (str): the model artifact OCID in model catalog
-    model_uri (str): uri to model files, can be local or in cloud storage
+    swagger_types : dict
+        The property names and the corresponding types of OCI ModelDeployment model.
+    model_id : str
+        The model artifact OCID in model catalog.
+    model_uri : str
+        uri to model files, can be local or in cloud storage.
 
     Methods
     -------
@@ -66,42 +69,51 @@ class ModelDeploymentProperties(
         Parameters
         ----------
         model_id : str
-            Model Artifact OCID. The model_id must be specified either explicitly or as an attribute of the OCI object.
+            Model Artifact OCID. The model_id must be specified either
+            explicitly or as an attribute of the OCI object.
         model_uri : str
             uri to model files, can be local or in cloud storage.
         oci_model_deployment: ModelDeployment or CreateModelDeploymentDetails or UpdateModelDeploymentDetails or dict
             An OCI model or dict containing model deployment details.
-            The OCI model can be an instance of either ModelDeployment, CreateModelDeploymentDetails or
-            UpdateModelConfigurationDetails.
+            The OCI model can be an instance of either ModelDeployment,
+            CreateModelDeploymentDetails or UpdateModelConfigurationDetails.
         config : dict
             ADS auth dictionary for OCI authentication.
-            This can be generated by calling ads.common.auth.api_keys() or ads.common.auth.resource_principal().
+            This can be generated by calling ads.common.auth.api_keys() or
+            ads.common.auth.resource_principal().
             If this is None, ads.common.default_signer(client_kwargs) will be used.
-        kwargs:
+        kwargs :
             Users can also initialize the object by using keyword arguments.
             The following keyword arguments are supported by OCI models:
-                'display_name'
-                'description'
-                'project_id'
-                'compartment_id'
-                'model_deployment_configuration_details',
-                'category_log_details',
-                'freeform_tags',
-                'defined_tags',
-            ModelDeploymentProperties also supports the following additional keyward arguments:
-                "instance_shape",
-                "instance_count",
-                "bandwidth_mbps",
-                "access_log_group_id",
-                "access_log_id",
-                "predict_log_group_id",
-                "predict_log_id",
-            These additional arguments will be saved into approperate properties in the OCI model.
+
+            - `display_name`,
+            - `description`,
+            - `project_id`,
+            - `compartment_id`,
+            - `model_deployment_configuration_details`,
+            - `category_log_details`,
+            - `freeform_tags`,
+            - `defined_tags`.
+
+            ModelDeploymentProperties also supports the following additional
+            keyward arguments:
+
+            - `instance_shape`,
+            - `instance_count`,
+            - `bandwidth_mbps`,
+            - `access_log_group_id`,
+            - `access_log_id`,
+            - `predict_log_group_id`,
+            - `predict_log_id`.
+
+            These additional arguments will be saved into appropriate properties
+            in the OCI model.
 
         Raises
         ------
-            ValueError: model_id is None AND not specified in
-            oci_model_deployment.model_deployment_configuration_details.model_configuration_details
+        ValueError
+            model_id is None AND not specified in
+            oci_model_deployment.model_deployment_configuration_details.model_configuration_details.
         """
         if not config:
             config = default_signer()
@@ -189,9 +201,11 @@ class ModelDeploymentProperties(
         config : dict
             dictionary containing instance configuration about the deployment.
             The following keys are supported:
-                instance_shape,
-                instance_count,
-                bandwidth_mbps.
+
+            - instance_shape,
+            - instance_count,
+            - bandwidth_mbps.
+
             The instance_shape and instance_count are required when creating a new deployment.
             They are optional when updating an existing deployment.
 
@@ -348,11 +362,11 @@ class ModelDeploymentProperties(
         property_name : str
             Name of a model deployment property.
         value :
-            New value for property attribute
+            New value for property attribute.
 
         Returns
         -------
-        ModelDeploymentProperties:
+        ModelDeploymentProperties
             self
 
         """
@@ -369,7 +383,7 @@ class ModelDeploymentProperties(
 
         Returns
         -------
-        CreateModelDeploymentDetails:
+        CreateModelDeploymentDetails
             A CreateModelDeploymentDetails instance ready for OCI API.
 
         """
@@ -380,7 +394,7 @@ class ModelDeploymentProperties(
                     display_name="testing",
                     project_id=self.project_id,
                     compartment_id=self.compartment_id,
-                )
+                ),
             )
             self.model_deployment_configuration_details.model_configuration_details.model_id = (
                 self.model_id
@@ -392,7 +406,7 @@ class ModelDeploymentProperties(
 
         Returns
         -------
-        CreateModelDeploymentDetails:
+        CreateModelDeploymentDetails
             An UpdateModelDeploymentDetails instance ready for OCI API.
 
         """
