@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from ads.secrets.secrets import *
 from ads.secrets.adb import *
 from ads.secrets.auth_token import *
+from ads.secrets.oracledb import *
+from ads.secrets.mysqldb import *
