@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import fsspec
@@ -10,6 +10,7 @@ import json
 import os
 from typing import Dict, Generator, List, Union
 
+from ads.common.runtime_dependency import runtime_dependency
 from ads.text_dataset.utils import PY4JGateway, experimental
 from fsspec.core import OpenFile
 
@@ -149,11 +150,10 @@ class Tika(Base):
 
 
 class PDFPlumber(Base):
+    @runtime_dependency(
+        module="pdfplumber", err_msg="pdfplumber must be installed first."
+    )
     def __init__(self):
-        try:
-            import pdfplumber
-        except ModuleNotFoundError as e:
-            raise ModuleNotFoundError("pdfplumber must be installed first.")
         super().__init__()
 
     def read_line(self, fhandler):
