@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 
@@ -144,6 +144,3 @@ class DocumentDetector(AbstractTypeDiscoveryDetector):
 
 if __name__ == "__main__":
     dd = DocumentDetector()
-
-    df = pd.read_csv('notebooks/datasets/papers.csv')
-    print(dd.discover("abstract", df.title))
