@@ -1,12 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from __future__ import print_function, absolute_import
 
-import dask.dataframe as dd
 import pandas as pd
 
 from ads.common import utils
@@ -20,7 +19,6 @@ from ads.type_discovery.latlon_detector import LatLonDetector
 from ads.type_discovery.phone_number_detector import PhoneNumberDetector
 from ads.type_discovery.unknown_detector import UnknownDetector
 from ads.type_discovery.zipcode_detector import ZipCodeDetector
-
 from ads.type_discovery.typed_feature import ContinuousTypedFeature
 
 #
@@ -74,9 +72,9 @@ class TypeDiscoveryDriver:
 
         """
 
-        assert isinstance(s, pd.Series) or isinstance(s, dd.Series), (
-            "Cannot perform type discovery on series that " "is not dask or ads."
-        )
+        assert (
+            type(s).__name__ == "Series"
+        ), "Type discovery can only be performed on a pandas.Series"
 
         if is_target and ContinuousDetector._target_is_continuous(s):
             return ContinuousTypedFeature.build(name, s)
