@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2020, 2021 Oracle and its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 
@@ -19,12 +19,12 @@ import scipy as sp
 from six import string_types
 from sklearn.utils import Bunch
 from sklearn.feature_extraction.text import CountVectorizer
-from wordcloud import STOPWORDS
 
-from ads.common import utils
+from ads.common import utils, logger
 from ads.common.card_identifier import card_identify
 from ads.common.utils import JsonConverter
 
+
 class TypedFeature(Bunch):
     def __init__(self, name, meta_data):
         assert "type" in meta_data
@@ -309,12 +309,23 @@ class DocumentTypedFeature(TypedFeature):
             # remove special characters and digits
             text = pat_digits.sub(" ", text)
 
+            stop_words = []
+            try:
+                from wordcloud import STOPWORDS
+
+                stop_words = STOPWORDS
+            except ModuleNotFoundError as e:
+                utils._log_missing_module("wordcloud", "oracle-ads[text]")
+                logger.info(
+                    "The stop words are ignored due to missing dependency wordcloud."
+                )
+
             # Convert to list from string and return a generator expression
             yield " ".join(
                 [
                     x
                     for x in pat_splitter.split(text)
-                    if len(x) >= 3 and x not in STOPWORDS
+                    if len(x) >= 3 and x not in stop_words
                 ]
             )
 
